**********************************************
**********************************************
*** ADDITIONAL DESCRIPTIVES FROM SUSENAS   ***
**********************************************
**********************************************

use data/codeddata/susenas2015.dta, clear

// selects non-poor informal households
bysort hhid: egen informalhh=max(informal*hhead)
g eligiblehh=(nonpoor==1&informalhh==1)

// selects households without health insurance
bysort hhid: egen hihh=max(hi) 
bysort hhid: egen jknhh=max(hi_bpjskesehatan)
g claim = inpind == 1 | outind == 1
bysort hhid: egen claimhh = max(claim)
bysort hhid: egen inphh = max(inpind)
g hi_nonjkn = hi - hi_bpjskesehatan
bysort hhid: egen hi_nonjknhh = max(hi_nonjkn)
g hi_sponsored = hi_jamesmas == 1 | hi_jamkesda == 1
bysort hhid: egen hi_sponsoredhh = max(hi_sponsored)

// creates variables
g expend_y = expend_m * 12
g share=oop_y/expend_y
g expend_y_nonhealth = expend_y - oop_y
g share_nonhealth=oop_y/expend_y_nonhealth

// 1. enrollment rates in JKN in 2015 for eligible households w/o other types of insurance
// (introduction)
su jknhh [aw=wert] if rtsample==1&eligiblehh==1&hi_nonjknhh==0

// 2. share of households with private insurance, and with no insurance
// (setting -- the Indonesian health system)
su hi_pri [aw=weind] 
su hi [aw=weind] 

// 3. oop for non-poor informal households without insurance
// (setting -- the Indonesian health system)
su oop_y [aw=wert] if rtsample==1&eligiblehh==1&hihh==0, d
su share_nonhealth [aw=wert] if rtsample==1&eligiblehh==1&hihh==0, d

// 4. share of households who are eligible
// (setting -- JKN Mandiri)
su eligiblehh [aw=wert] if rtsample==1
su hi_sponsoredhh [aw=wert] if rtsample==1&nonpoor==0

**********************************************
**********************************************
*** ADDITIONAL STATISTICS ABOUT SAMPLE     ***
**********************************************
**********************************************

// 1. number of households we listed
// (experimental design and data)
use data/raw/baseline_survey_bandung_public/fl2_s.dta, clear
append using data/raw/baseline_survey_medan_public/fl2_s.dta
count

// 2. number of households in the study
// (experimental design and data)
use data/codeddata/cleaned.dta, clear
unique hhid

// 3. number of households without NIK
use A:/baseline_survey_medan/b1_ar.dta, clear
append using A:/baseline_survey_bandung/B1_AR1.dta

g no_nik = (ar05_a==""&ar06_a=="")
su no_nik

// 4. share of control households with class3 membership
use data/codeddata/cleaned.dta, clear

// keeps the correct sample
keep if rtsample==1
keep if enroll==1
keep if paidrt_all_offer_1to12==1
keep if paidrt_signup1==1
keep if nosubsidy==1

g class3 = (mod(paidrt_ssp_amount_signup1, 25500)==0) if paidrt_ssp_amount_signup1!=0

su class3 [aw=weight]

