
***************************************
***************************************
*** FIGURE 1 -- CROSS RANDOMIZATION ***
***************************************
***************************************

use data/codeddata/cleaned.dta, clear

* sample restrictions
keep if rtsample==1
keep if restrictedsample==1
keep if pilot=="BANDUNG"

mat def A=J(8,4,.)

mat list A

g noonsite=1-onsite

local r=1
foreach subsidy in nosubsidy halfsubsidy fullsubsidy bonussubsidy {
	local c=1
	foreach registration in noonsite onsite {
		count if `subsidy'==1&`registration'==1&infomandate==0&infowaiting==0
		mat def A[`r',`c']=`r(N)'
		count if `subsidy'==1&`registration'==1&infomandate==1&infowaiting==0
		mat def A[`r',`c'+1]=`r(N)'
		count if `subsidy'==1&`registration'==1&infomandate==0&infowaiting==1
		mat def A[`r'+1,`c']=`r(N)'
		count if `subsidy'==1&`registration'==1&infomandate==1&infowaiting==1
		mat def A[`r'+1,`c'+1]=`r(N)'
		local c=`c'+2
		}
	local r=`r'+2
	}

mat list A

putexcel set output/figures/figure1A.xlsx, sheet("A") replace
putexcel A1=matrix(A)

use data/codeddata/cleaned.dta, clear

* sample restrictions
keep if rtsample==1
keep if restrictedsample==1
keep if pilot=="MEDAN"

mat def A=J(3,4,.)

mat list A

g noonsite=1-onsite

local r=1
foreach subsidy in nosubsidy halfsubsidy fullsubsidy {
	local c=1
	foreach registration in noonsite onsite {
		count if `subsidy'==1&`registration'==1&infoextra==0
		mat def A[`r',`c']=`r(N)'
		count if `subsidy'==1&`registration'==1&infoextra==1
		mat def A[`r',`c'+1]=`r(N)'
		local c=`c'+2
		}
	local r=`r'+1
	}
	
mat list A

putexcel set output/figures/figure1B.xlsx, sheet("B") replace
putexcel A1=matrix(A)

	
**********************************************************************
**********************************************************************
*** FIGURE 3 -- COVERAGE FOR SUBSIDY TREATMENT			  		   ***
**********************************************************************
**********************************************************************

*** PANEL A -- COVERAGE BY MONTHS SINCE OFFER	   ***

use data/codeddata/cleaned.dta, clear

* sample restrictions
keep if restrictedsample==1

* subsidy variable
cap drop subsidy
g subsidy=.
replace subsidy=1 if nosubsidy==1
replace subsidy=2 if halfsubsidy==1
replace subsidy=3 if fullsubsidy==1
replace subsidy=4 if bonussubsidy==1
drop if subsidy==.

keep if rtsample==1

keep paidrt_all_offer* hhid weight nosubsidy bonussubsidy halfsubsidy fullsubsidy

reshape long paidrt_all_offer, i(hhid) j(em_offer)

mat def A=J(72,3,.)

loc colnames ""

loc c=1
foreach var of varlist paidrt_all_offer {	
	loc r=1
	forvalues month=1(1)24 {
	
		qui ci means `var' [aw=weight] if em_offer==`month'&nosubsidy==1
		mat def A[`r',`c']=r(mean)
		mat def A[`r',`c'+1]=r(lb)
		mat def A[`r',`c'+2]=r(ub)
		
		qui ci means `var' [aw=weight] if em_offer==`month'&halfsubsidy==1
		mat def A[`r'+24,`c']=r(mean)
		mat def A[`r'+24,`c'+1]=r(lb)
		mat def A[`r'+24,`c'+2]=r(ub)
		
		qui ci means `var' [aw=weight] if em_offer==`month'&fullsubsidy==1
		mat def A[`r'+48,`c']=r(mean)
		mat def A[`r'+48,`c'+1]=r(lb)
		mat def A[`r'+48,`c'+2]=r(ub)
		
		loc ++r
		}
		
	loc c=`c'+3
	loc colnames	"`colnames' `var'_mean `var'_lb `var'_ub"
	}

di "`colnames'"	
mat colnames A = `colnames'

clear 
svmat A, names(col)
g em_offer=mod(_n,24)
replace em_offer=24 if em_offer==0
g subsidy=int((_n-1)/24)+1

label variable em_offer 				"Months since offer date"

replace em_offer=em_offer+0.15 if subsidy==2
replace em_offer=em_offer+0.30 if subsidy==3

keep if em_offer<21

#delimit ;
tw  (rcap paidrt_all_offer_ub paidrt_all_offer_lb em_offer if subsidy==1, sort(em_offer) lc(blue*0.5))
	(connected paidrt_all_offer_mean em_offer if subsidy==1, sort(em_offer) lp(longdash) lc(blue) mc(blue) s(diamond) msize(medium))
	(rcap paidrt_all_offer_ub paidrt_all_offer_lb em_offer if subsidy==2, sort(em_offer) lc(gs10*0.5))
	(connected paidrt_all_offer_mean em_offer if subsidy==2, sort(em_offer) lp(shortdash) lc(gs10) mc(gs10) s(circle) msize(medium))
	(rcap paidrt_all_offer_ub paidrt_all_offer_lb em_offer if subsidy==3, sort(em_offer) lc(red*0.5))
	(connected paidrt_all_offer_mean em_offer if subsidy==3, sort(em_offer) lc(red) mc(red) s(square) msize(medium)
	title("", c(black))
	legend(on order(2 4 6) label(2 "No subsidy") label(4 "Half subsidy") label(6 "Full subsidy") rows(1)  region(lc(white)))
	xlabel(1(1)20)
	ytitle("Share of HHs with coverage")
	ylabel(0(0.1)0.3, nogrid)
	xline(12.5, lc(gs10) lwidth(thin) lp(dash))
	graphregion(color(white))
	bgcolor(white));
#delimit cr

graph export output/figures/figure3A.pdf, replace
	
*** PANEL B -- COVERAGE BY MONTHS SINCE ENROLLMENT	   ***

use data/codeddata/cleaned.dta, clear

* sample restrictions
keep if enroll==1
keep if restrictedsample==1

* subsidy variable
cap drop subsidy
g subsidy=.
replace subsidy=1 if nosubsidy==1
replace subsidy=2 if halfsubsidy==1
replace subsidy=3 if fullsubsidy==1
replace subsidy=4 if bonussubsidy==1
drop if subsidy==.

// keeps the correct sample
keep if rtsample==1
keep if enroll==1
keep if paidrt_all_offer_1to12==1

// keeps vars
keep paidrt_signup* hhid subsidy weight weight nosubsidy bonussubsidy halfsubsidy fullsubsidy

// reshapes
reshape long paidrt_signup, i(hhid) j(em_signup)

mat def A=J(72,3,.)

loc colnames ""

loc c=1
foreach var of varlist paidrt_signup {	
	loc r=1
	forvalues month=1(1)24 {
	
		qui ci means `var' [aw=weight] if em_signup==`month'&nosubsidy==1
		mat def A[`r',`c']=r(mean)
		mat def A[`r',`c'+1]=r(lb)
		mat def A[`r',`c'+2]=r(ub)
		
		qui ci means `var' [aw=weight] if em_signup==`month'&halfsubsidy==1
		mat def A[`r'+24,`c']=r(mean)
		mat def A[`r'+24,`c'+1]=r(lb)
		mat def A[`r'+24,`c'+2]=r(ub)
		
		qui ci means `var' [aw=weight] if em_signup==`month'&fullsubsidy==1
		mat def A[`r'+48,`c']=r(mean)
		mat def A[`r'+48,`c'+1]=r(lb)
		mat def A[`r'+48,`c'+2]=r(ub)
		
		loc ++r
		}
		
	loc c=`c'+3
	loc colnames	"`colnames' `var'_mean `var'_lb `var'_ub"
	}

di "`colnames'"	
mat colnames A = `colnames'

clear 
svmat A, names(col)
g em_signup=mod(_n,24)
replace em_signup=24 if em_signup==0
g subsidy=int((_n-1)/24)+1

replace em_signup=em_signup+0.15 if subsidy==2
replace em_signup=em_signup+0.30 if subsidy==3

label variable em_signup 				"Months since enrollment"

keep if em_signup<21

#delimit ;
tw  (rcap paidrt_signup_ub paidrt_signup_lb em_signup if subsidy==1, sort(em_signup) lc(blue*0.5))
	(connected paidrt_signup_mean em_signup if subsidy==1, sort(em_signup) lc(blue) lp(longdash) mc(blue) s(diamond) msize(medium))
	(rcap paidrt_signup_ub paidrt_signup_lb em_signup if subsidy==2, sort(em_signup) lc(gs10*0.5))
	(connected paidrt_signup_mean em_signup if subsidy==2, sort(em_signup) lc(gs10) lp(shortdash) mc(gs10) s(circle) msize(medium))
	(rcap paidrt_signup_ub paidrt_signup_lb em_signup if subsidy==3, sort(em_signup) lc(red*0.5))
	(connected paidrt_signup_mean em_signup if subsidy==3, sort(em_signup) lc(red) mc(red) s(square) msize(medium)
	title("", c(black))
	xtitle("Months since enrollment", c(black))
	legend(on order(2 4 6) label(2 "No subsidy") label(4 "Half subsidy") label(6 "Full subsidy") rows(1)  region(lc(white)))
	xlabel(1(1)20)
	ytitle(Share of HHs with coverage, c(black))
	ylabel(0(0.25)1,nogrid)
	xline(12.5, lc(gs10) lwidth(thin) lp(dash))
	graphregion(color(white))
	bgcolor(white));
#delimit cr

graph export output/figures/figure3B.pdf, replace

	

		

**********************************************************************
**********************************************************************
*** FIGURE 4 -- COVERAGE FOR ONSITE REGISTRATION		  		   ***
**********************************************************************
**********************************************************************

*** PANEL A -- COVERAGE BY MONTHS SINCE OFFER	   ***

use data/codeddata/cleaned.dta, clear

* sample restrictions
keep if restrictedsample==1

keep if rtsample==1

keep paidrt_all_offer* hhid weight onsite

reshape long paidrt_all_offer, i(hhid) j(em_offer)

mat def A=J(48,3,.)

loc colnames ""

loc c=1
foreach var of varlist paidrt_all_offer {	
	loc r=1
	forvalues month=1(1)24 {
	
		qui ci means `var' [aw=weight] if em_offer==`month'&onsite==0
		mat def A[`r',`c']=r(mean)
		mat def A[`r',`c'+1]=r(lb)
		mat def A[`r',`c'+2]=r(ub)
		
		qui ci means `var' [aw=weight] if em_offer==`month'&onsite==1
		mat def A[`r'+24,`c']=r(mean)
		mat def A[`r'+24,`c'+1]=r(lb)
		mat def A[`r'+24,`c'+2]=r(ub)
				
		loc ++r
		}
		
	loc c=`c'+3
	loc colnames	"`colnames' `var'_mean `var'_lb `var'_ub"
	}

di "`colnames'"	
mat colnames A = `colnames'

clear 
svmat A, names(col)
g em_offer=mod(_n,24)
replace em_offer=24 if em_offer==0
g onsite=int((_n-1)/24)

label variable em_offer 				"Months since offer date"

replace em_offer=em_offer+0.15 if onsite==1

keep if em_offer<21

#delimit ;
tw  (rcap paidrt_all_offer_ub paidrt_all_offer_lb em_offer if onsite==0, sort(em_offer) lc(blue*0.5))
	(connected paidrt_all_offer_mean em_offer if onsite==0, sort(em_offer) lp(longdash) lc(blue) mc(blue) s(diamond) msize(medium))
	(rcap paidrt_all_offer_ub paidrt_all_offer_lb em_offer if onsite==1, sort(em_offer) lc(red*0.5))
	(connected paidrt_all_offer_mean em_offer if onsite==1, sort(em_offer) lc(red) mc(red) s(square) msize(medium)
	title("", c(black))
	legend(on order(2 4) label(2 "Status quo registration") label(4 "Assisted registration") rows(1)  region(lc(white)))
	xlabel(1(1)20)
	ytitle("Share of HHs with coverage")
	ylabel(0(0.025)0.125, nogrid)
	xline(12.5, lc(gs10) lwidth(thin) lp(dash))
	graphregion(color(white))
	bgcolor(white));
#delimit cr

graph export output/figures/figure4A.pdf, replace
	
	
*** PANEL B -- COVERAGE BY MONTHS SINCE ENROLLMENT	   ***
	

use data/codeddata/cleaned.dta, clear

* sample restrictions
keep if enroll==1
keep if restrictedsample==1

// keeps the correct sample
keep if rtsample==1
keep if enroll==1
keep if paidrt_all_offer_1to12==1

// keeps vars
keep paidrt_signup* hhid weight weight onsite

// reshapes
reshape long paidrt_signup, i(hhid) j(em_signup)

mat def A=J(48,3,.)

loc colnames ""

loc c=1
foreach var of varlist paidrt_signup {	
	loc r=1
	forvalues month=1(1)24 {
	
		qui ci means `var' [aw=weight] if em_signup==`month'&onsite==0
		mat def A[`r',`c']=r(mean)
		mat def A[`r',`c'+1]=r(lb)
		mat def A[`r',`c'+2]=r(ub)
		
		qui ci means `var' [aw=weight] if em_signup==`month'&onsite==1
		mat def A[`r'+24,`c']=r(mean)
		mat def A[`r'+24,`c'+1]=r(lb)
		mat def A[`r'+24,`c'+2]=r(ub)
				
		loc ++r
		}
		
	loc c=`c'+3
	loc colnames	"`colnames' `var'_mean `var'_lb `var'_ub"
	}

di "`colnames'"	
mat colnames A = `colnames'

clear 
svmat A, names(col)
g em_signup=mod(_n,24)
replace em_signup=24 if em_signup==0
g onsite=int((_n-1)/24)+1
tab onsite
replace em_signup=em_signup+0.15 if onsite==2

label variable em_signup 				"Months since enrollment"

keep if em_signup<21

#delimit ;
tw  (rcap paidrt_signup_ub paidrt_signup_lb em_signup if onsite==1, sort(em_signup) lc(blue*0.5))
	(connected paidrt_signup_mean em_signup if onsite==1, sort(em_signup) lc(blue) lp(longdash) mc(blue) s(diamond) msize(medium))
	(rcap paidrt_signup_ub paidrt_signup_lb em_signup if onsite==2, sort(em_signup) lc(red*0.5))
	(connected paidrt_signup_mean em_signup if onsite==2, sort(em_signup) lc(red) lp(shortdash) mc(red) s(circle) msize(medium)
	title("", c(black))
	xtitle("Months since enrollment", c(black))
	legend(on order(2 4 6) label(2 "Status quo") label(4 "Assisted registration") rows(1)  region(lc(white)))
	xlabel(1(1)20)
	ytitle(Share of HHs with coverage, c(black))
	ylabel(0(0.25)1,nogrid)
	xline(12.5, lc(gs10) lwidth(thin) lp(dash))
	graphregion(color(white))
	bgcolor(white));
#delimit cr

graph export output/figures/figure4B.pdf, replace

	
**********************************************************************
**********************************************************************
*** FIGURE 5 -- CLAIMS DYNAMICS BY SUBSIDY TREATMENT			   ***
**********************************************************************
**********************************************************************

use data/codeddata/cleaned.dta, clear

* sample restrictions
keep if enroll==1
keep if restrictedsample==1

* subsidy variable
cap drop subsidy
g subsidy=.
replace subsidy=1 if nosubsidy==1
replace subsidy=2 if halfsubsidy==1
replace subsidy=3 if fullsubsidy==1
replace subsidy=4 if bonussubsidy==1
drop if subsidy==.

// creates the variables for the graphs 
foreach var in any inp out anyhosp {
	forvalues month=1(1)24 {
		
		*AL LEAST ONE
		cap drop `var'rt_signup`month'
		bysort hhid: egen `var'rt_signup`month'=max(`var'ind_signup`month')
		
		*NUMBER
		cap drop `var'rtnum_signup`month'
		bysort hhid: egen `var'rtnum_signup`month'=sum(`var'indnum_signup`month')
		
		*VALUE
		if "`var'"!="out"&"`var'"!="anyhosp" {
			cap drop `var'rttotvalue_signup`month'
			bysort hhid: egen `var'rttotvalue_signup`month'=sum(`var'indtotvalue_signup`month')
			}
		}
	}

// keeps the correct sample
keep if rtsample==1
keep if enroll==1
keep if paidrt_all_offer_1to12==1

// keeps vars
keep paidrt_signup* hhid badhealthrt_mean subsidy weight anyrt* inprt* outrt* anyhosprt* weight nosubsidy bonussubsidy halfsubsidy fullsubsidy

// reshapes
reshape long paidrt_signup anyrt_signup inprt_signup outrt_signup anyhosprt_signup anyrtnum_signup inprtnum_signup outrtnum_signup anyhosprtnum_signup anyrttotvalue_signup inprttotvalue_signup, i(hhid) j(em_signup)

replace anyrttotvalue_signup=anyrttotvalue_signup/1000000
replace inprttotvalue_signup=inprttotvalue_signup/1000000

mat def A=J(72,24,.)

loc colnames ""

loc c=1
foreach var of varlist anyrt_signup outrt_signup inprt_signup anyrtnum_signup outrtnum_signup inprtnum_signup anyrttotvalue_signup inprttotvalue_signup {	
	loc r=1
	forvalues month=1(1)24 {
	
		qui ci means `var' [aw=weight] if em_signup==`month'&nosubsidy==1
		mat def A[`r',`c']=r(mean)
		mat def A[`r',`c'+1]=r(lb)
		mat def A[`r',`c'+2]=r(ub)
		
		qui ci means `var' [aw=weight] if em_signup==`month'&halfsubsidy==1
		mat def A[`r'+24,`c']=r(mean)
		mat def A[`r'+24,`c'+1]=r(lb)
		mat def A[`r'+24,`c'+2]=r(ub)
		
		qui ci means `var' [aw=weight] if em_signup==`month'&fullsubsidy==1
		mat def A[`r'+48,`c']=r(mean)
		mat def A[`r'+48,`c'+1]=r(lb)
		mat def A[`r'+48,`c'+2]=r(ub)
		
		loc ++r
		}
		
	loc c=`c'+3
	loc colnames	"`colnames' `var'_mean `var'_lb `var'_ub"
	}

di "`colnames'"	
mat colnames A = `colnames'

clear 
svmat A, names(col)
g em_signup=mod(_n,24)
replace em_signup=24 if em_signup==0
g subsidy=int((_n-1)/24)+1

replace em_signup=em_signup+0.15 if subsidy==2
replace em_signup=em_signup+0.30 if subsidy==3

label variable em_signup 				"months since enrollment"

keep if em_signup<21

#delimit ;
tw  (rcap anyrtnum_signup_ub anyrtnum_signup_lb em_signup if subsidy==1, sort(em_signup) lc(blue*0.5))
	(connected anyrtnum_signup_mean em_signup if subsidy==1, sort(em_signup) lc(blue) lp(longdash) mc(blue) s(diamond) msize(medium))
	(rcap anyrtnum_signup_ub anyrtnum_signup_lb em_signup if subsidy==2, sort(em_signup) lc(gs10*0.5))
	(connected anyrtnum_signup_mean em_signup if subsidy==2, sort(em_signup) lc(gs10) lp(shortdash) mc(gs10) s(circle) msize(medium))
	(rcap anyrtnum_signup_ub anyrtnum_signup_lb em_signup if subsidy==3, sort(em_signup) lc(red*0.5))
	(connected anyrtnum_signup_mean em_signup if subsidy==3, sort(em_signup) lc(red) mc(red) s(square) msize(medium)
	title("", c(black))
	xtitle("Months since enrollment", c(black))
	ytitle("Number of claims", c(black))
	legend(on order(2 4 6) label(2 "No subsidy") label(4 "Half subsidy") label(6 "Full subsidy") rows(1)  region(lc(white)))
	xlabel(1(1)20)
	ylabel(,nogrid)
	xline(12.5, lc(gs10) lwidth(thin) lp(dash))
	graphregion(color(white))
	bgcolor(white));
#delimit cr

graph export output/figures/figure5.pdf, replace

	




**********************************************************************
**********************************************************************
*** FIGURE 6 -- CLAIMS PDF       								   ***
**********************************************************************
**********************************************************************

use data/working/claims_cleaned_all.dta, clear
	
g yearmonth = ym(year(startdate),month(startdate)) 
format %tm yearmonth

// drop outind outindnum outhospind outhospindnum inpind inpindnum outhospindtotvalue inpindtotvalue

* creates the variables
g out=(servtype=="OUT")
g outhosp=(servtype=="OUT"&dataset=="HOSPITAL")
g inp=(servtype=="IN")
g value=byversjp

g membershipok=(membership=="PEKERJA BUKAN PENERIMA UPAH")
g signupdatesame=(signupdate==firstsignuprt)

merge m:1 perid membertag_final yearmonth using data/working/enrollment_month.dta

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                        11,451
//         from master                       409  (_merge==1)
//         from using                     11,042  (_merge==2)
// 
//     matched                             1,693  (_merge==3)
//     -----------------------------------------

// MAKES THE SAME CORRECTIONS AS IN THE MAIN CLEANING DO FILE
cap drop n
bysort perid membertag_final: g n=_n
bysort perid membertag_final: egen everpaid=max((_m==2|_m==3))
bysort perid membertag_final: egen correct=max(membershipok==1|signupdatesame==1)
tab _m if n==1
tab everpaid if _m==1&n==1, m
tab everpaid correct if _m==1&n==1, m 
cap drop temp

// LOADS THE CLAIMS IN THE MONTH IMMEDIATELY AFTER THEY STOP PAYING ONTO THE LAST MONTH
cap drop temp
g temp1=lastmonthpaid if everpaid==1
g temp2=em_offer if yearmonth==lastmonthpaid
g temp3=em_signup if yearmonth==lastmonthpaid
bysort perid membertag_final: egen lastmonthind=max(temp1)
bysort perid membertag_final: egen lastenrollmonthind=max(temp2)
bysort perid membertag_final: egen lastenrollmonthind_signup=max(temp3)
g monthsafter=yearmonth-lastmonthind
tab monthsafter if _m==1
replace em_offer=lastenrollmonthind if monthsafter==1&_m==1&em_offer==.

keep if _m==3
drop _m
keep if em_signup>=0&em_signup<=12

keep hhid perid membertag_final restrictedsample enroll description dataset nosubsidy halfsubsidy fullsubsidy onsitereg enroll enroll_ST enroll_LT restrictedsample out outhosp inp value kdinacbgs

// merges in paidrt
preserve
use data/codeddata/cleaned.dta, clear
keep perid membertag_final paidrt_all_offer_1to12
tempfile paidrt_all_offer_1to12
save `paidrt_all_offer_1to12'
restore

// merges weights
merge m:1 perid membertag_final using `paidrt_all_offer_1to12'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                        27,946
//         from master                         9  (_merge==1)
//         from using                     27,937  (_merge==2)
//
//     matched                             3,949  (_merge==3)
//     -----------------------------------------

keep if _m==3
drop _m

* keeps the correct sample
keep if restrictedsample==1
keep if enroll==1
keep if paidrt_all_offer_1to12==1

cap drop subsidy
g subsidy=.
replace subsidy=1 if nosubsidy==1
replace subsidy=2 if halfsubsidy==1
replace subsidy=3 if fullsubsidy==1

replace value=value/1000

foreach type in /*all out*/ inp {

	if "`type'"=="all"	local restriction 	""
	if "`type'"=="inp"	local restriction 	"&inp==1"
	if "`type'"=="out"	local restriction 	"&out==1"

	if "`type'"=="all"	local typetitle 	"All"
	if "`type'"=="inp"	local typetitle 	"Inpatient"
	if "`type'"=="out"	local typetitle 	"Outpatient"

	cap drop x fx*
	kdensity value if enroll_ST==1                   `restriction', nograph generate(x fx) 
	kdensity value if enroll_ST==1 & nosubsidy==1    `restriction', nograph generate(fx2) at(x)
	kdensity value if enroll_ST==1 & halfsubsidy==1  `restriction', nograph generate(fx0) at(x) 
	kdensity value if enroll_ST==1 & fullsubsidy==1  `restriction', nograph generate(fx1) at(x)
	
	label var fx0 "Half Subsidy"
	label var fx1 "Full Subsidy"
	label var fx2 "Zero Subsidy"
			
	#delimit ;
	twoway 	(line fx2 x, 	sort lc(blue) lw(medthick))
			(line fx0 x, 	sort lc(gs10) lw(medthick) lp(shortdash))
			(line fx1 x, 	sort lc(red) lw(medthick) lp(longdash)
							graphregion(color(white)) bgcolor(white)
							title("",  c(black))
							ylabel(, nogrid)
							legend(on order(1 2 3) label(1 "No subsidy") label(2 "Half subsidy") label(3 "Full subsidy") rows(1) region(lc(white)))
							ytitle("Density")
							xtitle("Value of claims (1,000 Rp.)"))
							;
	#delimit cr
	
	graph export output/figures/figure6_`type'.pdf, replace
	}
			
// Kolmogorov –Smirnov tests of the equality of distributions
ksmirnov value if inp==1&nosubsidy==1|inp==1&halfsubsidy==1, by(halfsubsidy) exact
ksmirnov value if inp==1&nosubsidy==1|inp==1&fullsubsidy==1, by(fullsubsidy) exact
	
				