	
***************************************
***************************************
*** TABLE 1: EFFECT ON ENROLLMENT   ***
***************************************
***************************************

*** PANEL A -- main effects ***

use data/codeddata/cleaned.dta, clear

keep if rtsample==1
keep if restrictedsample==1

local outcomes          	enroll enroll_ST enroll_LT
local regressors        	bonussubsidy fullsubsidy halfsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt pilotbandung oldr
local pvaltest              halfsubsidy onsitereg 
local esttabdefinition      esttab using output/tables/table1.csv, replace nogaps keep(halfsubsidy fullsubsidy onsitereg) order(fullsubsidy halfsubsidy onsitereg)  nonotes se(%9.3f) b(%9.3f) scalars(ymean_ctl p_halfsubsidy p_onsitereg) starlevels(* 0.10 ** 0.05 *** 0.01)

eststo clear
foreach outcome in `outcomes' {
	
	eststo: reg `outcome' `regressors' [aw=weight], r
	
	foreach x in `pvaltest' {
		test (`x'==fullsubsidy)
		estadd scalar p_`x'=r(p)
		}
	
	qui su `outcome' [aw=weight] if nosubsidy==1&onsite==0
	scalar ymean_ctl =  `r(mean)'
	estadd scalar ymean_ctl

	}

`esttabdefinition'
eststo clear

*** PANEL B -- information treatment, Medan ***

use data/codeddata/cleaned.dta, clear

keep if rtsample==1
keep if restrictedsample==1

local outcomes          	enroll enroll_ST enroll_LT    
local regressors        	halfsubsidy fullsubsidy onsitereg infoextra twoweekstmt choicetmt
local esttabdefinition      esttab using output/tables/table1.csv, append nogaps keep(infoextra) nonotes se(%9.3f) b(%9.3f) scalars(ymean_ctl p_halfsubsidy p_onsitereg) starlevels(* 0.10 ** 0.05 *** 0.01)

eststo clear
foreach outcome in `outcomes' {
	
	eststo: reg `outcome' `regressors' [aw=weight] if pilot=="MEDAN", r
	qui su `outcome' [aw=weight] if infoextra==0&pilot=="MEDAN"
	estadd scalar ymean_ctl=`r(mean)'
	}
	
`esttabdefinition'
eststo clear

*** PANEL C -- information treatments, Bandung ***

use data/codeddata/cleaned.dta, clear

keep if rtsample==1
keep if restrictedsample==1

local outcomes          	enroll enroll_ST enroll_LT    
local regressors        	bonussubsidy halfsubsidy fullsubsidy onsitereg infomandate infowaiting oldr
local esttabdefinition      esttab using output/tables/table1.csv, append nogaps keep(infomandate infowaiting) nonotes se(%9.3f) b(%9.3f) scalars(ymean_ctl p_halfsubsidy p_onsitereg) starlevels(* 0.10 ** 0.05 *** 0.01)

eststo clear
foreach outcome in `outcomes' {
	
	eststo: reg `outcome' `regressors' [aw=weight] if pilot=="BANDUNG", r
		
	qui su `outcome' [aw=weight] if infomandate==0&infowaiting==0&pilot=="BANDUNG" 
	estadd scalar ymean_ctl=`r(mean)'
	}
	
`esttabdefinition'
eststo clear


***********************************************
***********************************************
*** TABLE 2: EFFECT ON ATTEMPTED ENROLLMENT ***
***********************************************
***********************************************

*** PANEL A -- main effects ***

use data/codeddata/cleaned.dta, clear

keep if rtsample==1
keep if restrictedsample==1

local outcomes          	intentenroll_ST enroll_ST 
local regressors        	bonussubsidy fullsubsidy halfsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt pilotbandung oldr
local pvaltest              halfsubsidy onsitereg 
local esttabdefinition      esttab using output/tables/table2.csv, replace nogaps keep(onsitereg) order(onsitereg)  nonotes se(%9.3f) b(%9.3f) scalars(ymean_ctl) starlevels(* 0.10 ** 0.05 *** 0.01)

eststo clear
foreach outcome in `outcomes' {
	
	eststo: reg `outcome' `regressors' [aw=weight], r
		
	qui su `outcome' [aw=weight] if onsitereg==0
	scalar ymean_ctl =  `r(mean)'
	estadd scalar ymean_ctl

	}

`esttabdefinition'
eststo clear

*** PANEL B -- interactions ***

use data/codeddata/cleaned.dta, clear

keep if rtsample==1
keep if restrictedsample==1

local outcomes          	intentenroll_ST enroll_ST 
local regressors        	bonussubsidy_statusquoreg halfsubsidy_statusquoreg fullsubsidy_statusquoreg nosubsidy_onsitereg bonussubsidy_onsitereg halfsubsidy_onsitereg fullsubsidy_onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt pilotbandung oldr
local esttabdefinition      esttab using output/tables/table2.csv, append nogaps keep(nosubsidy_statusquoreg halfsubsidy_statusquoreg fullsubsidy_statusquoreg nosubsidy_onsitereg halfsubsidy_onsitereg fullsubsidy_onsitereg) order(fullsubsidy_onsitereg fullsubsidy_statusquoreg halfsubsidy_onsitereg halfsubsidy_statusquoreg nosubsidy_onsitereg nosubsidy_statusquoreg) scalars(ymean_ctl) nonotes se(%9.3f) b(%9.3f) starlevels(* 0.10 ** 0.05 *** 0.01)

eststo clear
foreach outcome in `outcomes' {
	
	eststo: reg `outcome' `regressors' [aw=weight], r
	
	qui su `outcome' [aw=weight] if nosubsidy==1&onsitereg==0
	estadd scalar ymean_ctl=`r(mean)'
	}
	
`esttabdefinition'
eststo clear




**********************************************
**********************************************
*** TABLE 3: REASONS FOR FAILING TO ENROLL ***
**********************************************
**********************************************

use data/codeddata/cleaned.dta, clear
keep if intentenroll_ST==1&enroll_ST==0&onsitereg==1&restrictedsample==1
keep if rtsample==1

// if two visits and both fail, keep second reason
g whyfailed=.
replace whyfailed=vc03c
replace whyfailed=vc03c_1 if vc03c==.|vc03c!=.&vc03c_1!=.
g whyfailed_ot=""
replace whyfailed_ot=vc03c_ot
replace whyfailed_ot=vc03c_1_ot if vc03c_ot==""|vc03c_ot!=""&vc03c_1_ot!=""

g technicalreason=0
replace technicalreason=1 if whyfailed==1|whyfailed==2

g familycard=0
replace familycard=1 if whyfailed==3|whyfailed==4|whyfailed==5|whyfailed==6
replace familycard=1 if whyfailed==95&whyfailed_ot=="ADA SALAH SATU ANGGOTA KELUARGA YANG SUDAH MENINGGAL DAN MASIH MASUK DALAM KK"
replace familycard=1 if whyfailed==95&whyfailed_ot=="ALAMAT DIKARTU KELUARGA TIDAK TERDAFTAR DI SISTEM ONLINE"
replace familycard=1 if whyfailed==95&whyfailed_ot=="DATA KK TIDAK SESUAI DENGAN DATABASE BPJS"
replace familycard=1 if whyfailed==95&whyfailed_ot=="ADA ANGGOTA KELUARGA YANG BELUM TERDAFTAR DI KARTU KK"
replace familycard=1 if whyfailed==95&whyfailed_ot=="KARTU KELUARGA DAN KTP MASIH DALAM PROSES PEMBUATAN"
replace familycard=1 if whyfailed==95&whyfailed_ot=="BELUM MEMILIKI KARTU KELUARGA"
replace familycard=1 if whyfailed==95&whyfailed_ot=="KK BELUM UPDATE"
replace familycard=1 if whyfailed==95&whyfailed_ot=="KK BELUM YANG TERBARU DAN AKAN BERKUNJUNG KE BPJS LANGSUNG."
replace familycard=1 if whyfailed==95&whyfailed_ot=="RESPONDEN BELUM MEMILIKI NOMER REKENING DAN INGIN MENDAFTAR KE BPJS LANGSUNG."
replace familycard=1 if whyfailed==95&whyfailed_ot=="KELUARGA INI TDK MENGETAHUI KALAU SALAH 1 ANGGOTA KELUARGA TLH TERDAFTAR BPJS"
replace familycard=1 if whyfailed==95&whyfailed_ot=="KK YANG ADA BELUM DI PERBARUI KARNA MENAMBAH ANGGOTA KELUARGA BARU"
replace familycard=1 if whyfailed==95&whyfailed_ot=="SALAH SATU NAMA ANGGOTA YANG TERDAFTAR DI KK TIDAK TERCANTUM DI SISTEM ONLINE BP"
replace familycard=1 if whyfailed==95&whyfailed_ot=="KK MASIH KK YANG LAMA DAN DI BPJS TIDAK TERDAFTAR"

g familycard_alreadyreg=0
replace familycard_alreadyreg=1 if whyfailed==5
g familycard_notfound=0
replace familycard_notfound=1 if whyfailed==4
g familycard_incorrect=0
replace familycard_incorrect=1 if whyfailed==6
g familycard_other=0
replace familycard_other=1 if familycard==1&familycard_alreadyreg==0&familycard_notfound==0&familycard_incorrect==0

g other=0
replace other=1 if whyfailed==7|whyfailed==95&familycard==0

g missing=0
replace missing=1 if whyfailed==.

drop if missing==1

mat def A=J(8,2,.)

qui count if familycard==1
mat def A[1,1]=`r(N)'
qui su familycard
mat def A[1,2]=`r(mean)'

qui count if other==1
mat def A[2,1]=`r(N)'
qui su other
mat def A[2,2]=`r(mean)'

qui count if technicalreason==1
mat def A[3,1]=`r(N)'
qui su technicalreason
mat def A[3,2]=`r(mean)'

qui count if familycard_other==1
mat def A[4,1]=`r(N)'
qui su familycard_other if familycard==1
mat def A[4,2]=`r(mean)'

qui count if familycard_incorrect==1
mat def A[5,1]=`r(N)'
qui su familycard_incorrect if familycard==1
mat def A[5,2]=`r(mean)'

qui count if familycard_notfound==1
mat def A[6,1]=`r(N)'
qui su familycard_notfound if familycard==1
mat def A[6,2]=`r(mean)'

qui count if familycard_alreadyreg==1
mat def A[7,1]=`r(N)'
qui su familycard_alreadyreg if familycard==1
mat def A[7,2]=`r(mean)'


mat list A
putexcel set output/tables/table3.xlsx, replace
putexcel A1=matrix(A)






******************************************************
******************************************************
*** TABLE 4: CLAIMS BY MONTHS SINCE ENROLLMENT	   ***
******************************************************
******************************************************

use data/codeddata/cleaned.dta, clear

// tab  badhealthrt
// g goodhealthrt = 1 - badhealthrt

// selects the sample: ENROLL==1 & RESTRICTEDSAMPLE==1 & PAID FOR AT LEAST ONE MONTH
keep if rtsample==1
keep if restrictedsample==1
keep if enroll==1
keep if paidrt_all_offer_1to12==1

// windorised claims
replace anyrttotvalue_signup_1to12=anyrttotvalue_signup_1to12/1000000
g anyrttotvalue_signup_1to12_w=anyrttotvalue_signup_1to12
su anyrttotvalue_signup_1to12_w [aw=weight], d
replace anyrttotvalue_signup_1to12_w=`r(p99)' if anyrttotvalue_signup_1to12_w>=`r(p99)'

// days to first claim
su daystofirstclaimrt_signup_1to12 if enroll==1&restrictedsample==1&paidrt_all_offer_1to12==1, d
replace daystofirstclaimrt_signup_1to12=`r(max)' if daystofirstclaimrt_signup_1to12==.&enroll==1&restrictedsample==1&paidrt_all_offer_1to12==1

local outcomes				"badhealthrt_mean anyrt_signup_1to12 chronicrt_signup_1to12 anyrtnum_signup_1to12 chronicrtnum_signup_1to12 anyrttotvalue_signup_1to12_w daystofirstclaimrt_signup_1to12"

g no_onsite = 1 - onsitereg

// gets enrollment
mat def A=J(15,11,.)

local col = 1
foreach outcome in `outcomes' {	
	// covered household-month
	local row = 1
	foreach tmt in  fullsubsidy halfsubsidy nosubsidy onsitereg no_onsite  {
		su `outcome' [aw=weight] if `tmt'==1
		mat def A[`row',`col']=`r(mean)'
		mat def A[`row'+1,`col']=`r(sd)'
		local row=`row'+2
		}
	qui count 
	mat def A[`row',`col']=`r(N)'
	local ++row
	reg `outcome' bonussubsidy halfsubsidy fullsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt pilotbandung oldr [aw=weight], r
	foreach tmt in fullsubsidy halfsubsidy onsitereg {
		test `tmt'
		mat def A[`row',`col'] = `r(p)'
		local ++row
		}
	test fullsubsidy = halfsubsidy
	mat def A[`row',`col'] = `r(p)'
	local ++row
	local ++col	
	}

mat list A, format(%9.3f)
putexcel set output/tables/table4.xlsx, sheet("A") replace
putexcel A1=matrix(A)





/////////////////
/////////////////
//// TABLE 5 ////
/////////////////
/////////////////

use data/codeddata/cleaned.dta, clear

keep if rtsample==1
keep if restrictedsample==1
keep if enroll==1
keep if paidrt_all_offer_1to12==1

// g stayers = paidrt_signup15
// g droppers = 1 - paidrt_signup15
g stayers = enrolled_and_paid_yr1_stayed
g droppers = enrolled_and_paid_yr1_dropped
 
// windorised claims
replace anyrttotvalue_signup_1to12=anyrttotvalue_signup_1to12/1000000
g anyrttotvalue_signup_1to12_w=anyrttotvalue_signup_1to12
su anyrttotvalue_signup_1to12_w [aw=weight], d
replace anyrttotvalue_signup_1to12_w=`r(p99)' if anyrttotvalue_signup_1to12_w>=`r(p99)'

// days to first claim
su daystofirstclaimrt_signup_1to12 if enroll==1&restrictedsample==1&paidrt_all_offer_1to12==1, d
replace daystofirstclaimrt_signup_1to12=`r(max)' if daystofirstclaimrt_signup_1to12==.&enroll==1&restrictedsample==1&paidrt_all_offer_1to12==1

mat def A=J(17,8,.)

local outcomes	"badhealthrt_mean anyrt_signup_1to12 chronicrt_signup_1to12 anyrtnum_signup_1to12 chronicrtnum_signup_1to12 anyrttotvalue_signup_1to12_w daystofirstclaimrt_signup_1to12"

eststo clear
local col = 1
foreach outcome in `outcomes' {
	local row = 1
	
	// stayers versus droppers by subsidy treatment
	foreach tmt in fullsubsidy halfsubsidy nosubsidy {
	
		// droppers mean
		su `outcome' [aw=weight] if `tmt'==1&stayers==0
		mat def A[`row',`col']=`r(mean)'
		mat def A[`row'+1,`col']=`r(sd)'
		mat def A[`row',8]=`r(N)'
		
		// stayers mean
		su `outcome' [aw=weight] if `tmt'==1&stayers==1
		mat def A[`row'+2,`col']=`r(mean)'
		mat def A[`row'+3,`col']=`r(sd)'
		mat def A[`row'+2,8]=`r(N)'
		
		// t-test of the difference
		reg `outcome' stayers [aw=weight] if `tmt'==1, r
		mat def A[`row'+4,`col']=2*ttail(e(df_r),abs( _b[stayers]/_se[stayers]))
		
		local row = `row' + 5
		}
	
	// stayers in full subsidy versus no subsidy
	reg `outcome' halfsubsidy fullsubsidy bonussubsidy [aw=weight] if stayers==1, r
	mat def A[16,`col']=2*ttail(e(df_r),abs( _b[fullsubsidy]/_se[fullsubsidy]))
	mat def A[17,`col']=2*ttail(e(df_r),abs( _b[halfsubsidy]/_se[halfsubsidy]))
			
	local ++col
	}
	
mat list A, format(%9.3f)
putexcel set output/tables/table5.xlsx, sheet("A") replace
putexcel A1=matrix(A)



**********************************************
**********************************************
*** TABLE 6: PROFITABILITY				   ***
**********************************************
**********************************************

*** PANEL A ***

use data/codeddata/cleaned.dta, clear

keep if rtsample==1
keep if restrictedsample==1

// gets enrollment
mat def A=J(10,5,.)

egen paidrt_all_offer_1to12_num=rsum(paidrt_all_offer1 paidrt_all_offer2 paidrt_all_offer3 paidrt_all_offer4 paidrt_all_offer5 paidrt_all_offer6 paidrt_all_offer7 paidrt_all_offer8 paidrt_all_offer9 paidrt_all_offer10 paidrt_all_offer11 paidrt_all_offer12)

local row = 1
local col = 1
foreach tmt in fullsubsidy halfsubsidy nosubsidy {
	su paidrt_all_offer_1to12_num [aw=weight] if `tmt'==1
	mat def A[`row',`col']=`r(mean)'
	mat def A[`row'+1,`col']=`r(sd)'
	local row=`row'+2
	}
qui count 
mat def A[`row',`col']=`r(N)'
local ++row
reg paidrt_all_offer_1to12_num bonussubsidy halfsubsidy fullsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt pilotbandung oldr [aw=weight], r
foreach tmt in fullsubsidy halfsubsidy {
	test `tmt'
	mat def A[`row',`col'] = `r(p)'
	local ++row
	}
test halfsubsidy = fullsubsidy 
mat def A[`row',`col'] = `r(p)'

keep hhid paidrt_all_offer* paidrt_ssp_amount_offer* paidrt_ssp_offer* anyrtotvalue_offer_* nosubsidy  bonussubsidy halfsubsidy  ///
	 fullsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt ///
	 pilotbandung oldr enroll paidrt_all_offer_1to12  weight restrictedsample hhsize_payment_all

reshape long paidrt_all_offer paidrt_ssp_amount_offer paidrt_ssp_offer anyrtotvalue_offer_, i(hhid) j(month_since_offer)

keep if month_since_offer>=1&month_since_offer<=12

ren anyrtotvalue_offer_ anyrtotvalue_offer

// variables in mIDR
// paidrt_ssp_amount: month 1-12 since offer
foreach var of varlist paidrt_ssp_amount_offer anyrtotvalue_offer {
	replace `var'=`var'/1000
	replace `var'=0 if `var'==.
	}

// count if anyrtotvalue_offer!=.&anyrtotvalue_offer!=0&paidrt_all_offer==0
// count if anyrtotvalue_offer!=.&anyrtotvalue_offer!=0&paidrt_all_offer==1	
replace anyrtotvalue_offer=0 if paidrt_all_offer==0

// windorizes claims
foreach var in 	anyrtotvalue_offer {
	g `var'_w=`var'
	su `var' [aw=weight] if enroll==1&restrictedsample==1&paidrt_all_offer==1, d
	replace `var'_w=`r(p99)' if `var'_w>=`r(p99)'&`var'_w!=.
	}

// profit
g profit_offer=(paidrt_ssp_amount-anyrtotvalue_offer)
g profit_offer_with_cap=(paidrt_ssp_amount-anyrtotvalue_offer-paidrt_all_offer*hhsize_payment_all*6800/1000)

local col = 2
foreach outcome in paidrt_ssp_amount anyrtotvalue_offer profit_offer profit_offer_with_cap {	
	
	// all household-month
	local row = 1
	foreach tmt in fullsubsidy halfsubsidy nosubsidy {
		su `outcome' [aw=weight] if `tmt'==1
		mat def A[`row',`col']=`r(mean)'
		mat def A[`row'+1,`col']=`r(sd)'
		local row=`row'+2
		}
	qui count 
	mat def A[`row',`col']=`r(N)'
	local ++row
	reg `outcome' bonussubsidy halfsubsidy fullsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt pilotbandung oldr [aw=weight], cluster(hhid)
	foreach tmt in fullsubsidy halfsubsidy {
		test `tmt'
		mat def A[`row',`col'] = `r(p)'
		local ++row
		}
	test halfsubsidy = fullsubsidy 
	mat def A[`row',`col'] = `r(p)'

	local ++col	
	}

mat list A, format(%9.3f)
putexcel set output/tables/table6.xlsx, sheet("A") replace
putexcel A1=matrix(A)



*** PANEL B ***

use data/codeddata/cleaned.dta, clear

keep if rtsample==1
keep if restrictedsample==1

egen paidrt_all_offer_13to20_num=rsum(paidrt_all_offer13 paidrt_all_offer14 paidrt_all_offer15 paidrt_all_offer16 paidrt_all_offer17 paidrt_all_offer18 paidrt_all_offer19 paidrt_all_offer20)

// gets enrollment
mat def A=J(10,5,.)

local row = 1
local col = 1
foreach tmt in fullsubsidy halfsubsidy nosubsidy {
	su paidrt_all_offer_13to20_num [aw=weight] if `tmt'==1
	mat def A[`row',`col']=`r(mean)'
	mat def A[`row'+1,`col']=`r(sd)'
	local row=`row'+2
	}
qui count 
mat def A[`row',`col']=`r(N)'
local ++row
reg paidrt_all_offer_13to20_num bonussubsidy halfsubsidy fullsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt pilotbandung oldr [aw=weight], r
foreach tmt in fullsubsidy halfsubsidy {
	test `tmt'
	mat def A[`row',`col'] = `r(p)'
	local ++row
	}
test halfsubsidy = fullsubsidy 
mat def A[`row',`col'] = `r(p)'

g stub=(enroll_2yrs==1&fullsubsidy==1&paidrt_jpalamount_offer2!=0&paidrt_jpalamount_offer1==0| ///
		enroll_2yrs==1&halfsubsidy==1&paidrt_jpalamount_offer2!=0&paidrt_jpalamount_offer1==0)
g month13 = stub * paidrt_ssp_offer13 + (1-stub) * paidrt_all_offer13
egen paidrt_ssp_amount_13to20=rsum(month13 paidrt_allamount_offer14 paidrt_allamount_offer15 paidrt_allamount_offer16 paidrt_allamount_offer17 paidrt_allamount_offer18 paidrt_allamount_offer19 paidrt_allamount_offer20)
drop paidrt_allamount_offer13
ren  month13 paidrt_allamount_offer13

keep hhid paidrt_all_offer* paidrt_allamount_offer* paidrt_ssp_offer* anyrtotvalue_offer_* nosubsidy  bonussubsidy halfsubsidy  ///
	 fullsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt ///
	 pilotbandung oldr enroll paidrt_all_offer_1to12  weight restrictedsample hhsize_payment_all

reshape long paidrt_all_offer paidrt_allamount_offer anyrtotvalue_offer_, i(hhid) j(month_since_offer)

g post_enrollment=paidrt_all_offer
bysort hhid (month_since_offer): replace post_enrollment=1 if post_enrollment[_n-1]==1

keep if month_since_offer>=13&month_since_offer<=20

ren anyrtotvalue_offer_ anyrtotvalue_offer

// variables in mIDR
// paidrt_ssp_amount: month 1-12 since offer
foreach var of varlist paidrt_allamount_offer anyrtotvalue_offer {
	replace `var'=`var'/1000
	replace `var'=0 if `var'==.
	}

// count if anyrtotvalue_offer!=.&anyrtotvalue_offer!=0&paidrt_all_offer==0
// count if anyrtotvalue_offer!=.&anyrtotvalue_offer!=0&paidrt_all_offer==1	
replace anyrtotvalue_offer=0 if paidrt_all_offer==0

// windorizes claims
foreach var in 	anyrtotvalue_offer {
	g `var'_w=`var'
	su `var' [aw=weight] if enroll==1&restrictedsample==1&paidrt_all_offer==1, d
	replace `var'_w=`r(p99)' if `var'_w>=`r(p99)'&`var'_w!=.
	}

	
// profit
g profit_offer=(paidrt_allamount_offer-anyrtotvalue_offer)
g profit_offer_with_cap=(paidrt_allamount_offer-anyrtotvalue_offer-6800*hhsize_payment_all/1000*paidrt_all_offer)

local col = 2
foreach outcome in paidrt_allamount_offer anyrtotvalue_offer profit_offer profit_offer_with_cap {	

	// all household-month
	local row = 1
	foreach tmt in fullsubsidy halfsubsidy nosubsidy {
		su `outcome' [aw=weight] if `tmt'==1
		mat def A[`row',`col']=`r(mean)'
		mat def A[`row'+1,`col']=`r(sd)'
		local row=`row'+2
		}
	qui count 
	mat def A[`row',`col']=`r(N)'
	local ++row
	reg `outcome' bonussubsidy halfsubsidy fullsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt pilotbandung oldr [aw=weight], cluster(hhid)
	foreach tmt in fullsubsidy halfsubsidy {
		test `tmt'
		mat def A[`row',`col'] = `r(p)'
		local ++row
		}
	test halfsubsidy = fullsubsidy 
	mat def A[`row',`col'] = `r(p)'

	local ++col	
	}

mat list A, format(%9.3f)
putexcel set output/tables/table6.xlsx, sheet("A") modify
putexcel A11=matrix(A)
