
**********************************************
**********************************************
*** APPENDIX TABLE 1: SUSENAS DESCRIPTIVES ***
**********************************************
**********************************************

// PANEL A: ALL HOUSEHOLDS

use data/codeddata/susenas2015.dta, clear

cap drop out_mult
cap drop inp_mult
egen out_mult = rsum(outind_public_hospital outind_puskesmas outind_ukbm outind_private_hospital outind_doctor outind_clinic outind_traditional)
tab out_mult

egen inp_mult = rsum(inpind_public_hospital inpind_private_hospital inpind_doctor inpind_clinic inpind_puskesmas inpind_traditional)
tab inp_mult

foreach var of varlist inpind_* {
	replace `var'=0 if inp_mult!=1
	}
foreach var of varlist outind_* {
	replace `var'=0 if out_mult!=1
	}

g inpind_public = inpind_public_hospital + inpind_puskesmas
g inpind_PUB_public = inpind_PUB_public_hospital + inpind_PUB_puskesmas
g inpind_PRI_public = inpind_PRI_public_hospital + inpind_PRI_puskesmas

g inpind_private = inpind_private_hospital + inpind_doctor + inpind_clinic
g inpind_PUB_private = inpind_PUB_private_hospital + inpind_PUB_doctor + inpind_PUB_clinic
g inpind_PRI_private = inpind_PRI_private_hospital + inpind_PRI_doctor + inpind_PRI_clinic

g outind_public = outind_public_hospital + outind_puskesmas + outind_ukbm
g outind_PUB_public = outind_PUB_public_hospital + outind_PUB_puskesmas + outind_PUB_ukbm
g outind_PRI_public = outind_PRI_public_hospital + outind_PRI_puskesmas + outind_PRI_ukbm

g outind_private = outind_private_hospital + outind_doctor + outind_clinic
g outind_PUB_private = outind_PUB_private_hospital + outind_PUB_doctor + outind_PUB_clinic
g outind_PRI_private = outind_PRI_private_hospital + outind_PRI_doctor + outind_PRI_clinic

g all = 1

collapse (sum) inpind_* outind_* [aw=weind], by(all)

ren *_public_hospital 	*_1
ren *_puskesmas			*_2
ren *_ukbm				*_3
ren *_public			*_4

ren *_private_hospital	*_5
ren *_doctor			*_6
ren *_clinic			*_7
ren *_private			*_8

ren *_traditional		*_9

reshape long inpind_ inpind_PUB_ inpind_PRI_ outind_ outind_PUB_ outind_PRI_, i(all) j(type)

ren *_ *

cap drop temp
g temp = outind 
replace temp = 0 if type == 4 | type == 8
bysort all: egen out_all = total(temp)

cap drop temp
g temp = inpind 
replace temp = 0 if type == 4 | type == 8
bysort all: egen inp_all = total(temp)

g inp_share_all = inpind / inp_all
g inp_share_public = inpind_PUB / inpind
g inp_share_private = inpind_PRI / inpind

g out_share_all = outind / out_all
g out_share_public = outind_PUB / outind
g out_share_private = outind_PRI / outind

keep type *share*

list 

export excel using output/tables/Atable1_panelA.xlsx, replace

// PANEL B: NON POOR INFORMAL HOUSEHOLDS

use data/codeddata/susenas2015.dta, clear

cap drop out_mult
cap drop inp_mult
egen out_mult = rsum(outind_public_hospital outind_puskesmas outind_ukbm outind_private_hospital outind_doctor outind_clinic outind_traditional)
tab out_mult

egen inp_mult = rsum(inpind_public_hospital inpind_private_hospital inpind_doctor inpind_clinic inpind_puskesmas inpind_traditional)
tab inp_mult

foreach var of varlist inpind_* {
	replace `var'=0 if inp_mult!=1
	}
foreach var of varlist outind_* {
	replace `var'=0 if out_mult!=1
	}

g inpind_public = inpind_public_hospital + inpind_puskesmas
g inpind_PUB_public = inpind_PUB_public_hospital + inpind_PUB_puskesmas
g inpind_PRI_public = inpind_PRI_public_hospital + inpind_PRI_puskesmas

g inpind_private = inpind_private_hospital + inpind_doctor + inpind_clinic
g inpind_PUB_private = inpind_PUB_private_hospital + inpind_PUB_doctor + inpind_PUB_clinic
g inpind_PRI_private = inpind_PRI_private_hospital + inpind_PRI_doctor + inpind_PRI_clinic

g outind_public = outind_public_hospital + outind_puskesmas + outind_ukbm
g outind_PUB_public = outind_PUB_public_hospital + outind_PUB_puskesmas + outind_PUB_ukbm
g outind_PRI_public = outind_PRI_public_hospital + outind_PRI_puskesmas + outind_PRI_ukbm

g outind_private = outind_private_hospital + outind_doctor + outind_clinic
g outind_PUB_private = outind_PUB_private_hospital + outind_PUB_doctor + outind_PUB_clinic
g outind_PRI_private = outind_PRI_private_hospital + outind_PRI_doctor + outind_PRI_clinic
	
g all = 1

// selects sample
bysort hhid: egen informalhh=max(informal*hhead)
g eligiblehh=(nonpoor==1&informalhh==1)

keep if eligiblehh==1

collapse (sum) inpind_* outind_* [aw=weind], by(all)

ren *_public_hospital 	*_1
ren *_puskesmas			*_2
ren *_ukbm				*_3
ren *_public			*_4

ren *_private_hospital	*_5
ren *_doctor			*_6
ren *_clinic			*_7
ren *_private			*_8

ren *_traditional		*_9

reshape long inpind_ inpind_PUB_ inpind_PRI_ outind_ outind_PUB_ outind_PRI_, i(all) j(type)

ren *_ *

cap drop temp
g temp = outind 
replace temp = 0 if type == 4 | type == 8
bysort all: egen out_all = total(temp)

cap drop temp
g temp = inpind 
replace temp = 0 if type == 4 | type == 8
bysort all: egen inp_all = total(temp)

g inp_share_all = inpind / inp_all
g inp_share_public = inpind_PUB / inpind
g inp_share_private = inpind_PRI / inpind

g out_share_all = outind / out_all
g out_share_public = outind_PUB / outind
g out_share_private = outind_PRI / outind

keep type *share*

list 

export excel using output/tables/Atable1_panelB.xlsx, replace

	
	
	
******************************************************************
******************************************************************
*** APPENDIX TABLE 2: RANDOMIZATION BALANCE, RESTRICTED SAMPLE ***
******************************************************************
******************************************************************

*** Appendix Table 1 -- panel A ***

use data/codeddata/cleaned.dta, clear

bysort hhid: g hhsize=_N

// selects the sample
keep if rtsample==1
keep if restrictedsample==1

replace hasnikrt=0 if hasnikrt==.
replace hhsize=. if badhealthrt_mean==.

local outcomes          	hasnikrt badhealthrt_mean outpatvisit inpatvisit chronic plus60 hhh_highschool employed hhsize  
local regressors        	bonussubsidy halfsubsidy fullsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt pilotbandung oldr
local esttabdefinition      esttab using output/tables/Atable2.csv, replace nogaps keep(halfsubsidy fullsubsidy onsitereg infoextra infomandate infowaiting) order(fullsubsidy halfsubsidy onsitereg) nonotes se(%9.3f) b(%9.3f) starlevels(* 0.10 ** 0.05 *** 0.01)

eststo clear
foreach outcome in `outcomes' {
	
	eststo: reg `outcome' `regressors' [aw=weight], r
	
	}
	
`esttabdefinition'
eststo clear




**********************************************************
**********************************************************
*** APPENDIX TABLE 3: OTHER TREATMENTS 				   ***
**********************************************************
**********************************************************

*** PANEL A -- Medan ***

use data/codeddata/cleaned.dta, clear

keep if rtsample==1

local outcomes          	enroll enroll_ST enroll_LT 
local regressors        	bonussubsidy halfsubsidy fullsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt pilotbandung oldr
local esttabdefinition      esttab using output/tables/Atable3.csv, replace nogaps keep(twoweekstmt choicetmt) nonotes se(%9.3f) b(%9.3f) scalars(ymean_ctl) starlevels(* 0.10 ** 0.05 *** 0.01)

eststo clear
foreach outcome in `outcomes' {
	
	eststo: reg `outcome' `regressors' [aw=weight] if restrictedsample==1&pilot=="MEDAN", r
		
	qui su `outcome' [aw=weight] if nosubsidy==1&restrictedsample==1&pilot=="MEDAN"
	scalar ymean_ctl =  `r(mean)'
	estadd scalar ymean_ctl

	}

`esttabdefinition'
eststo clear

*** PANEL B -- Bandung ***

use data/codeddata/cleaned.dta, clear

keep if rtsample==1

local outcomes          	enroll enroll_ST enroll_LT 
local regressors        	bonussubsidy halfsubsidy fullsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt pilotbandung oldr
local esttabdefinition      esttab using output/tables/Atable3.csv, append nogaps keep(bonussubsidy) nonotes se(%9.3f) b(%9.3f) scalars(ymean_ctl) starlevels(* 0.10 ** 0.05 *** 0.01)

eststo clear
foreach outcome in `outcomes' {
	
	eststo: reg `outcome' `regressors' [aw=weight] if restrictedsample==1&pilot=="BANDUNG", r
		
	qui su `outcome' [aw=weight] if nosubsidy==1&restrictedsample==1&pilot=="BANDUNG"
	scalar ymean_ctl =  `r(mean)'
	estadd scalar ymean_ctl

	}

`esttabdefinition'
eststo clear



***************************************
***************************************
*** APPENDIX TABLE 4 -- PAYMENTS	***
***************************************
***************************************

use data/codeddata/cleaned.dta, clear

// selects the sample: ENROLL==1 & RESTRICTEDSAMPLE==1 & PAID FOR AT LEAST ONE MONTH
keep if rtsample==1
keep if restrictedsample==1
g no_onsite = 1 - onsitereg
mat def A=J(9,8,.)

g enrolled_and_paid_yr2_m20 = (enroll_2yrs==1&restrictedsample==1&paidrt_all_offer20==1)

local col = 1
foreach sample in enrolled_and_paid_yr1 enrolled_and_paid_yr1_dropped enrolled_and_paid_yr1_stayed enrolled_and_paid_yr2 enrolled_and_paid_yr2_m20 {	
	local row = 1
	foreach tmt in  fullsubsidy halfsubsidy nosubsidy onsitereg no_onsite {
		su `sample' [aw=weight] if `tmt'==1
		mat def A[`row',`col']=`r(mean)'
		local ++row
		}
	qui count 
	mat def A[`row',`col']=`r(N)'
	local ++row
	reg `sample' bonussubsidy halfsubsidy fullsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt pilotbandung oldr  [aw=weight], r
	foreach tmt in fullsubsidy halfsubsidy onsitereg {
		test `tmt'
		mat def A[`row',`col'] = `r(p)'
		local ++row
		}
		
	if `col'==3|`col'==5|`col'==7 {
		local col=`col'+2
		}
	else {
		local ++col
		}
	}

// 2. versus 3.

preserve
ren enrolled_and_paid_yr1_dropped x0
ren enrolled_and_paid_yr1_stayed  x1

keep hhid x* weight nosubsidy bonussubsidy halfsubsidy fullsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt pilotbandung oldr

reshape long x, i(hhid) j(sample)

g no_onsite = 1 - onsitereg

local row=1
foreach tmt in fullsubsidy halfsubsidy nosubsidy onsitereg no_onsite {
	reg x sample [aw=weight] if `tmt'==1, cluster(hhid)
	mat def A[`row',4] = 2*ttail(e(df_r),abs( _b[sample]/_se[sample]))
	local ++row
	}

restore 
	
// 1. versus 5.

preserve
ren enrolled_and_paid_yr1 x0
ren enrolled_and_paid_yr2 x1

keep hhid x* weight nosubsidy bonussubsidy halfsubsidy fullsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt pilotbandung oldr

reshape long x, i(hhid) j(sample)

g no_onsite = 1 - onsitereg

local row=1
foreach tmt in fullsubsidy halfsubsidy nosubsidy onsitereg no_onsite {
	reg x sample [aw=weight] if `tmt'==1, cluster(hhid)
	mat def A[`row',6] = 2*ttail(e(df_r),abs( _b[sample]/_se[sample]))
	local ++row
	}

restore 

	
// 1. versus 7.

preserve
ren enrolled_and_paid_yr1 x0
ren enrolled_and_paid_yr2_m20 x1

keep hhid x* weight nosubsidy bonussubsidy halfsubsidy fullsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt pilotbandung oldr

reshape long x, i(hhid) j(sample)

g no_onsite = 1 - onsitereg

local row=1
foreach tmt in fullsubsidy halfsubsidy nosubsidy onsitereg no_onsite {
	reg x sample [aw=weight] if `tmt'==1, cluster(hhid)
	mat def A[`row',8] = 2*ttail(e(df_r),abs( _b[sample]/_se[sample]))
	local ++row
	}

restore 
	
mat list A, format(%9.3f)
putexcel set output/tables/Atable4.xlsx, sheet("A") replace
putexcel A1=matrix(A)



***************************************************
***************************************************
*** APPENDIX TABLE 5 -- PAYMENTS, REGRESSIONS	***
***************************************************
***************************************************

// appendix table 
use data/codeddata/cleaned.dta, clear

// selects the sample: ENROLL==1 & RESTRICTEDSAMPLE==1 
keep if rtsample==1
keep if restrictedsample==1

eststo clear
// 1.
eststo: reg enrolled_and_paid_yr1 bonussubsidy halfsubsidy fullsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt pilotbandung oldr [aw=weight], r
qui su enrolled_and_paid_yr1 [aw=weight] if nosubsidy==1&restrictedsample==1
estadd scalar ymean_ctl=`r(mean)'

// 2.
eststo: reg enrolled_and_paid_yr1_dropped bonussubsidy halfsubsidy fullsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt pilotbandung oldr [aw=weight], r
qui su enrolled_and_paid_yr1_dropped [aw=weight] if nosubsidy==1&restrictedsample==1
estadd scalar ymean_ctl=`r(mean)'

// 3.
eststo: reg enrolled_and_paid_yr1_stayed bonussubsidy halfsubsidy fullsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt pilotbandung oldr [aw=weight], r
qui su enrolled_and_paid_yr1_stayed [aw=weight] if nosubsidy==1&restrictedsample==1
estadd scalar ymean_ctl=`r(mean)'

// 4.
eststo: reg enrolled_and_paid_yr2 bonussubsidy halfsubsidy fullsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt pilotbandung oldr [aw=weight], r
qui su enrolled_and_paid_yr2 [aw=weight] if nosubsidy==1&restrictedsample==1
estadd scalar ymean_ctl=`r(mean)'

// 5.
g enrolled_and_paid_yr2_m20 = (enroll_2yrs==1&restrictedsample==1&paidrt_all_offer20==1)
eststo: reg enrolled_and_paid_yr2_m20 bonussubsidy halfsubsidy fullsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt pilotbandung oldr [aw=weight], r
qui su enrolled_and_paid_yr2_m20 [aw=weight] if nosubsidy==1&restrictedsample==1
estadd scalar ymean_ctl=`r(mean)'

esttab using output/tables/Atable5.csv, replace nogaps keep(sample halfsubsidy* fullsubsidy* onsitereg*) ///
							order(sample fullsubsidy* halfsubsidy* onsitereg*) nonotes se(%9.3f) b(%9.3f) ///
							scalar(ymean_ctl) starlevels(* 0.10 ** 0.05 *** 0.01)



******************************************************************************************
******************************************************************************************
*** APPENDIX TABLE 6: SELF-REPORTED HEALTH AND CLAIMS IN 12 MONTHS SINCE ENROLLMENT	   ***
*** REGRESSIONS										                                   ***
******************************************************************************************
******************************************************************************************

use data/codeddata/cleaned.dta, clear

// selects the correct sample
keep if rtsample==1
keep if restrictedsample==1
keep if enroll==1
keep if paidrt_all_offer_1to12==1

// windorised claims
replace anyrttotvalue_signup_1to12=anyrttotvalue_signup_1to12/1000000
g anyrttotvalue_signup_1to12_w=anyrttotvalue_signup_1to12
su anyrttotvalue_signup_1to12 [aw=weight], d
replace anyrttotvalue_signup_1to12_w=`r(p99)' if anyrttotvalue_signup_1to12_w>=`r(p99)'

// days to first claim
su daystofirstclaimrt_signup_1to12, d
replace daystofirstclaimrt_signup_1to12=`r(max)' if daystofirstclaimrt_signup_1to12==.

local outcomes				"anyrt_signup_1to12 chronicrt_signup_1to12 anyrtnum_signup_1to12 chronicrtnum_signup_1to12 anyrttotvalue_signup_1to12_w daystofirstclaimrt_signup_1to12"
local regressors			"badhealthrt_mean"
local esttabdefinition		esttab using output/tables/Atable6.csv, replace nogaps keep(badhealthrt_mean) nonotes se(%9.3f) b(%9.3f) scalars(ymean_ctl) starlevels(* 0.10 ** 0.05 *** 0.01) r2

eststo clear
foreach regressor in `regressors' {
	foreach outcome in `outcomes' {
		eststo: reg `outcome' `regressor' bonussubsidy halfsubsidy fullsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt pilotbandung oldr [aw=weight] if enroll==1&restrictedsample==1, r 
		}
			
}
		
`esttabdefinition'
eststo clear



******************************************************************************************
******************************************************************************************
*** APPENDIX TABLE 7: SELF-REPORTED HEALTH AND CLAIMS IN 12 MONTHS SINCE ENROLLMENT	   ***
*** REGRESSIONS 																	   ***
******************************************************************************************
******************************************************************************************

use data/codeddata/cleaned.dta, clear

// selects the sample: ENROLL==1 & RESTRICTEDSAMPLE==1 & PAID FOR AT LEAST ONE MONTH
keep if rtsample==1
keep if restrictedsample==1
keep if enroll==1
keep if paidrt_all_offer_1to12==1

// windorised claims
replace anyrttotvalue_signup_1to12=anyrttotvalue_signup_1to12/1000000
g anyrttotvalue_signup_1to12_w=anyrttotvalue_signup_1to12
su anyrttotvalue_signup_1to12_w [aw=weight], d
replace anyrttotvalue_signup_1to12_w=`r(p99)' if anyrttotvalue_signup_1to12_w>=`r(p99)'

// days to first claim
su daystofirstclaimrt_signup_1to12 if enroll==1&restrictedsample==1&paidrt_all_offer_1to12==1, d
replace daystofirstclaimrt_signup_1to12=`r(max)' if daystofirstclaimrt_signup_1to12==.&enroll==1&restrictedsample==1&paidrt_all_offer_1to12==1

local outcomes				"badhealthrt_mean anyrt_signup_1to12 chronicrt_signup_1to12 anyrtnum_signup_1to12 chronicrtnum_signup_1to12 anyrttotvalue_signup_1to12_w daystofirstclaimrt_signup_1to12"
local regressors			bonussubsidy halfsubsidy fullsubsidy onsitereg infoextra infomandate infowaiting twoweekstmt choicetmt pilotbandung oldr
local esttabdefinition		esttab using output/tables/Atable7.csv, replace nogaps keep(halfsubsidy fullsubsidy onsitereg) order(fullsubsidy halfsubsidy onsitereg) nonotes se(%9.3f) b(%9.3f) scalars(ymean_ctl)  starlevels(* 0.10 ** 0.05 *** 0.01)

eststo clear
foreach outcome in `outcomes' {
			
	eststo: reg `outcome' `regressors' [aw=weight] if enroll==1&restrictedsample==1&paidrt_all_offer_1to12==1, r
	qui sum `outcome' [aw=weight] if nosubsidy==1&restrictedsample==1&enroll==1&paidrt_all_offer_1to12==1
	estadd scalar ymean_ctl=`r(mean)'

	}
	
`esttabdefinition'
eststo clear



***************************************************************
***************************************************************
*** APPENDIX TABLE 8: STAYERS AND DROPPERS, REGISTRATION   ***
***************************************************************
***************************************************************

use data/codeddata/cleaned.dta, clear

keep if rtsample==1
keep if restrictedsample==1
keep if enroll==1
keep if paidrt_all_offer_1to12==1

g stayers = enrolled_and_paid_yr1_stayed
g droppers = enrolled_and_paid_yr1_dropped

g noonsite = 1 - onsitereg

// windorised claims
replace anyrttotvalue_signup_1to12=anyrttotvalue_signup_1to12/1000000
g anyrttotvalue_signup_1to12_w=anyrttotvalue_signup_1to12
su anyrttotvalue_signup_1to12_w [aw=weight], d
replace anyrttotvalue_signup_1to12_w=`r(p99)' if anyrttotvalue_signup_1to12_w>=`r(p99)'

// days to first claim
su daystofirstclaimrt_signup_1to12 if enroll==1&restrictedsample==1&paidrt_all_offer_1to12==1, d
replace daystofirstclaimrt_signup_1to12=`r(max)' if daystofirstclaimrt_signup_1to12==.&enroll==1&restrictedsample==1&paidrt_all_offer_1to12==1

mat def A=J(11,8,.)

local outcomes	"badhealthrt_mean anyrt_signup_1to12 chronicrt_signup_1to12 anyrtnum_signup_1to12 chronicrtnum_signup_1to12 anyrttotvalue_signup_1to12_w daystofirstclaimrt_signup_1to12"

eststo clear
local col = 1
foreach outcome in `outcomes' {
	local row = 1
	
	// stayers versus droppers by subsidy treatment
	foreach tmt in onsitereg noonsite {
	
		// droppers mean
		su `outcome' [aw=weight] if `tmt'==1&stayers==0
		mat def A[`row',`col']=`r(mean)'
		mat def A[`row'+1,`col']=`r(sd)'
		mat def A[`row',8]=`r(N)'
		
		// stayers mean
		su `outcome' [aw=weight] if `tmt'==1&stayers==1
		mat def A[`row'+2,`col']=`r(mean)'
		mat def A[`row'+3,`col']=`r(sd)'
		mat def A[`row'+2,8]=`r(N)'
		
		// t-test of the difference
		reg `outcome' stayers [aw=weight] if `tmt'==1, r
		mat def A[`row'+4,`col']=2*ttail(e(df_r),abs( _b[stayers]/_se[stayers]))
		
		local row = `row' + 5
		}
	
	// stayers in onsite versus no status quo
	reg `outcome' onsitereg [aw=weight] if stayers==1, r
	mat def A[11,`col']=2*ttail(e(df_r),abs( _b[onsitereg]/_se[onsitereg]))
			
	local ++col
	}
	
mat list A, format(%9.3f)
putexcel set output/tables/Atable8.xlsx, sheet("A") replace
putexcel A1=matrix(A)
	
		
	
