**************************************************
* BANDUNG BASELINE PART I	  					 *
**************************************************

***A. Survey date***

use data/raw/baseline_survey_bandung_public/b1_time.dta, clear

keep hhid ivw* *vc time_occ*
format ivwdayb1 ivwmthb1 beg* end* %02.0f
tostring ivwdayb1 ivwmthb1 beg* end*, format(%02.0f) replace
format ivwyrb1 %04.0f
tostring ivwyrb1, format(%04.0f) replace
generate begvc = ivwyrb1+ivwmthb1+ivwdayb1+beghr_vc+begmin_vc
generate double vctime_beg = clock(begvc, "YMDhm")		
keep ivw* hhid vctime* time_occ*
bysort hhid: egen offertime = min(vctime_beg)
g offerdate = dofc(offertime)
format vctime* offertime %tc
format %td offerdate 
duplicates drop hhid, force
drop if offerdate ==.

keep hhid offerdate

g oldr=0
replace oldr=1 if year(offerdate)==2015&month(offerdate)==10
replace oldr=1 if year(offerdate)==2015&month(offerdate)==11&day(offerdate)<=10

tempfile time
save `time', replace

***B. Demographics***

***B.1 Chronic diseases***

use data/raw/baseline_survey_bandung_public/b1_cd.dta, clear 

bysort hhid: egen meanchronic=mean(cd01)
gen chronic = 0
replace chronic = 1 if meanchronic ~= 3
label variable chronic "Have any chronic disease"

label define yesno 1 "1. Yes" 0 "0. No"
local diseasename "diabetes heart stroke gout lung hypertension liver asthma"
local j = 1
foreach letter in A B C D E F G H {				
		local disname : word `j' of `diseasename'		
		dis "`j' `disname'"
		replace cdtype = "`disname'" if cdtype == "`letter'"
		local ++j
		}
		
reshape wide cd01 cd02 cd03, i(hhid) j(cdtype) string	
forvalues j=1/8 {
		local disname : word `j' of `diseasename'		  
		dis "`j' `disname'"
		label variable cd01`disname' "Ever been diagnosed with `disname'"
		label variable cd02`disname' "Number of family members diagnosed with `disname'"
		label variable cd03`disname' "Prescribed meds for`disname'"
		replace cd01`disname' = 0 if cd01`disname' == 3	
		ren cd01`disname' `disname'
		ren cd02`disname' `disname'size
		ren cd03`disname' `disname'drug
		}
drop meanchronic 
drop *size *drug 

tempfile cd
save `cd', replace

***B.2 Inpatient and outpatient history***

use data/raw/baseline_survey_bandung_public/b1_kk1.dta, clear 

gen 	outpatvisit = 0
replace outpatvisit = 1 if kk01 == 1
gen  	inpatvisit = 0
replace inpatvisit = 1 if kk05 == 1
gen 	inpatpredict = 0
replace inpatpredict = 1 if kk09 >= 3
rename kk10 inpatcostpredict
order hhid outpatvisit inpatvisit inpatpredict inpatcostpredict

replace inpatcostpredict= subinstr(inpatcostpredict,"_","",.)
replace inpatcostpredict= subinstr(inpatcostpredict,".","",.)
destring inpatcostpredict, replace

replace inpatcostpredict = . if inpatcostpredict >.
label variable inpatcostpredict ""

keep hhid *visit *predict
tempfile kk
save `kk', replace

***B.3 Outpatient cost***

use data/raw/baseline_survey_bandung_public/b1_kk2.dta, clear 

local outpatfacility "hospital puskesmas clinic midwife traditional"
local letter "A B C E F"

reshape wide kk02 kk03 kk04, i(hhid) j(kk1type) string
forvalues j=1/5{
		local outpatfac : word `j' of `outpatfacility'
		local let : word `j' of `letter'
		rename kk02`let' `outpatfac'outpatvisit
		label  variable `outpatfac'outpatvisit "Received outpatient care in `outpatfac'"
		rename kk03`let' `outpatfac'outpatfreq
		label  variable `outpatfac'outpatfreq "Frequency of outpatient care in `outpatfac'"
		rename kk04`let' `outpatfac'outpatcost
		label  variable `outpatfac'outpatcost "Cost outpatient care in `outpatfac'"
		}

foreach var of varlist *outpatcost {
	replace `var'="" if `var'=="999.999.998"
	replace `var'= subinstr(`var',"_","",.)
	replace `var'= subinstr(`var',".","",.)
	destring `var', replace
	}
	
egen outpatcost=rsum(*outpatcost)
keep hhid outpatcost 

tempfile outpatcost
save `outpatcost', replace 

***B.4 Inpatient cost***

use data/raw/baseline_survey_bandung_public/b1_kk3.dta, clear

drop kk2type_ot
local inpatfacility "hospital puskesmas clinic other"
local letter "A B C V"
reshape wide kk06 kk07 kk08, i(hhid) j(kk2type) string
forvalues j=1/4{
		local inpatfac : word `j' of `inpatfacility'
		local let : word `j' of `letter'
		rename kk06`let' `inpatfac'inpatvisit
		label  variable `inpatfac'inpatvisit "Received inpatient care in `inpatfac'"
		rename kk07`let' `inpatfac'inpatfreq
		label  variable `inpatfac'inpatfreq "Frequency of inpatient care in `inpatfac'"
		rename kk08`let' `inpatfac'inpatcost
		label  variable `inpatfac'inpatcost "Cost inpatient care in `inpatfac'"
		}
foreach var of varlist *inpatcost {
	replace `var'="" if `var'=="999.999.998"
	replace `var'= subinstr(`var',"_","",.)
	replace `var'= subinstr(`var',".","",.)
	destring `var', replace
	}
egen inpatcost=rsum(*inpatcost)
keep hhid inpatcost 

tempfile inpatcost
save `inpatcost', replace 

***B.6 Head of household's education***

use data/raw/baseline_survey_bandung_public/b1_ar.dta, clear 

bysort hhid: gen hhheduc = ar02 if ar00 == 1
bysort hhid: egen hhhedulevel = max(hhheduc)
replace hhhedulevel = . if hhhedulevel==9
label define edulabel 1  "Partial SD" /// 
                      2  "SD"       ///
					  3  "SMP"      ///
					  4  "SMA"      ///
					  5  "Diploma/Univ" ///
					  9  "Missing"
label value hhhedulevel edulabel						  
generate hhhedu = hhhedulevel*3
replace  hhhedu = hhhedu+1 if hhhedu==15 

duplicates drop hhid, force
g hhh_highschool=0
replace hhh_highschool=1 if hhhedulevel>=4&hhhedu!=.
keep hhid hhhedu hhh_highschool hhhedulevel

tempfile ed
save `ed', replace

***B.7 Head of household occupation***

use data/raw/baseline_survey_bandung_public/fl2_s.dta, clear 
rename s7 occ
label define occlabel 	1  "self-employed" /// 
						2  "self-employed with temp/unpaid workers"    ///
						3  "self-employed with perm/paid workers"      ///
						4  "employed"      ///
						5  "day-worker" ///
						6  "unpaid family worker" ///
						7  "unemployed"
label value occ occlabel						  				
g employed=0
replace employed=1 if occ!=7	
g formal=0
replace formal=1 if occ==4|occ==3	
g informal=0
replace informal=1 if occ==1|occ==2|occ==5|occ==6
keep hhid employed formal informal occ

tempfile occupation
save `occupation', replace

***B.8 JKN knowledge***

use data/raw/baseline_survey_bandung_public/b1_pj.dta, clear

tab pj01 //JKN familiarity
tab pj02 //JKN knowledge test
label variable pj01 "JKN awareness"
rename pj01 awarejkn
replace awarejkn=0 if awarejkn==3
g knowjkn=0
replace knowjkn=1 if pj02==3

keep hhid awarejkn knowjkn
label variable knowjkn "Identify JKN membership correctly"

tempfile jknknowledge
save `jknknowledge', replace

***B.9 HH size and location***

use data/raw/baseline_survey_bandung_public/b1_ar.dta, clear

generate kab = "BANDUNG"
generate desa = substr(hhid,1,3)
destring desa, replace

bysort hhid: gen hhsize = _N
duplicates drop hhid, force
keep hhid hhsize kab desa

tempfile familysize
save `familysize', replace

***B.10 documents***

use data/raw/baseline_survey_bandung_public/b1_kd.dta, clear

g temp=0
replace temp=1 if kd01==3&kd03==1
bysort hhid: egen mandatedocument=max(temp)

duplicates drop hhid mandatedocument, force

keep hhid mandatedocument

tempfile documents
save `documents', replace

***B.11 risk preferences***
use data/raw/baseline_survey_bandung_public/b1_ps.dta, clear

g procrastinates=0
replace procrastinates=1 if ps01==3

g gambleaverse=0
replace gambleaverse=1 if  ps02a1==1|ps02a1_1==1

* codes as risk averse households that choose the two "more risk averse" options
g riskaverse=0
replace riskaverse=1 if  ps02b==1|ps02b_1==1

* codes as risk averse households that choose the two "more risk averse" options + those who are gamble averse
g riskaverse_v2=0
replace riskaverse_v2=1 if  ps02b==1|ps02b_1==1
replace riskaverse_v2=1 if gambleaverse==1

g childrenexpect=0
replace childrenexpect=ps03 if ps03!=.&ps03!=98&ps03!=96
replace childrenexpect=ps03_1 if ps03_1!=.&ps03_1!=98&ps03_1!=96

keep hhid  procrastinates gambleaverse riskaverse riskaverse_v2 childrenexpect

tempfile risk
save `risk', replace

***B.11 Expects inpatient***
use data/raw/baseline_survey_bandung_public/b1_kk1.dta, clear

g expectinpatient=0
replace expectinpatient=1 if kk09==3|kk09==4

foreach var of varlist kk10 {
	replace `var'= subinstr(`var',"_","",.)
	replace `var'= subinstr(`var',".","",.)
	destring `var', replace
	}

su kk10, d
g costabovemedian=0
replace costabovemedian=1 if kk10>=`r(p50)'

keep hhid expectinpatient costabovemedian

tempfile expectations
save `expectations', replace

***B.11 Expects inpatient cost***
use data/raw/baseline_survey_bandung_public/b1_pk1.dta, clear

foreach var of varlist pk04 {
	replace `var'="" if `var'=="999.999.999.998"
	replace `var'="" if `var'=="999.999.999.999"
	replace `var'="" if `var'=="999.999.999.997"
	replace `var'= subinstr(`var',"_","",.)
	replace `var'= subinstr(`var',".","",.)
	destring `var', replace
	}

g hhincome=pk04

keep hhid hhincome

tempfile hhincome
save `hhincome', replace

***Merges Bandung baseline***

use `kk', clear	

merge 1:1 hhid using `cd'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                             1
//         from master                         1  (_merge==1) partial baseline, yes treatment
//         from using                          0  (_merge==2)
//
//     matched                             5,659  (_merge==3)
//     -----------------------------------------

count if _m!=3
assert `r(N)'==1
count if _m!=3&hhid=="823A010282"
assert `r(N)'==1
drop _merge

merge 1:1 hhid using `time'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                             7
//         from master                         0  (_merge==1)
//         from using                          7  (_merge==2)
//
//     matched                             5,660  (_merge==3)
//     -----------------------------------------
// 
// 5 households who refused baseline and treatment --> drop
// 2 households who refused baseline but received treatment --> keep

count if _m!=3
assert `r(N)'==7
count if _m!=3&hhid=="805A010068"|_m!=3&hhid=="805A010174"|_m!=3&hhid=="807A010206"|_m!=3&hhid=="809F010368"|_m!=3&hhid=="810C010198"
assert `r(N)'==5
drop if _m!=3&hhid=="805A010068"|_m!=3&hhid=="805A010174"|_m!=3&hhid=="807A010206"|_m!=3&hhid=="809F010368"|_m!=3&hhid=="810C010198"
drop _merge

count
loc temp `r(N)'

merge 1:1 hhid using `occupation'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                        39,394
//         from master                         0  (_merge==1)
//         from using                     39,394  (_merge==2) other listed households
//
//     matched                             5,662  (_merge==3)
//     -----------------------------------------

count if _m==3
assert `r(N)'==`temp'
drop if _m==2
drop _merge

merge 1:1 hhid using `ed'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                             2
//         from master                         2  (_merge==1) no baseline, yes treatment
//         from using                          0  (_merge==2)
//
//     matched                             5,660  (_merge==3)
//     -----------------------------------------

count if _m!=3
assert `r(N)'==2
count if _m!=3&hhid=="801D010048"|_m!=3&hhid=="809F010189"
assert `r(N)'==2
drop _merge

merge 1:1 hhid using `outpatcost' 

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                         3,639
//         from master                     3,639  (_merge==1) households w/o outpatient
//         from using                          0  (_merge==2)
//
//     matched                             2,023  (_merge==3)
//     -----------------------------------------

g m_outpatcost=_merge
replace outpatcost=0 if outpatcost==.&outpatvisit!=.
drop _merge

merge 1:1 hhid using `inpatcost' 

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                         5,316
//         from master                     5,316  (_merge==1) households w/o inpatient
//         from using                          0  (_merge==2)
//
//     matched                               346  (_merge==3)
//     -----------------------------------------

replace inpatcost=0 if inpatcost==.&inpatvisit!=.
drop _merge

merge 1:1 hhid using `jknknowledge' 

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                             2
//         from master                         2  (_merge==1) no baseline, yes treatment
//         from using                          0  (_merge==2)
//
//     matched                             5,660  (_merge==3)
//     -----------------------------------------

count if _m!=3
assert `r(N)'==2
count if _m!=3&hhid=="801D010048"|_m!=3&hhid=="809F010189"
assert `r(N)'==2
drop _merge

merge 1:1 hhid using `familysize' 

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                             2
//         from master                         2  (_merge==1) no baseline, yes treatment
//         from using                          0  (_merge==2)
//
//     matched                             5,660  (_merge==3)
//     -----------------------------------------

count if _m!=3
assert `r(N)'==2
count if _m!=3&hhid=="801D010048"|_m!=3&hhid=="809F010189"
assert `r(N)'==2
drop _merge

merge 1:1 hhid using `documents' 

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                             2
//         from master                         2  (_merge==1) no baseline, yes treatment
//         from using                          0  (_merge==2)
//
//     matched                             5,660  (_merge==3)
//     -----------------------------------------

count if _m!=3
assert `r(N)'==2
count if _m!=3&hhid=="801D010048"|_m!=3&hhid=="809F010189"
assert `r(N)'==2
drop _merge

merge 1:1 hhid using `risk' 

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                             2
//         from master                         2  (_merge==1) no baseline, yes treatment
//         from using                          0  (_merge==2)
//
//     matched                             5,660  (_merge==3)
//     -----------------------------------------

count if _m!=3
assert `r(N)'==2
count if _m!=3&hhid=="801D010048"|_m!=3&hhid=="809F010189"
assert `r(N)'==2
drop _merge

merge 1:1 hhid using `expectations' 

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                             2
//         from master                         2  (_merge==1) no baseline, yes treatment
//         from using                          0  (_merge==2)
//
//     matched                             5,660  (_merge==3)
//     -----------------------------------------

count if _m!=3
assert `r(N)'==2
count if _m!=3&hhid=="801D010048"|_m!=3&hhid=="809F010189"
assert `r(N)'==2
drop _merge

merge 1:1 hhid using `hhincome'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                             2
//         from master                         2  (_merge==1) no baseline, yes treatment
//         from using                          0  (_merge==2)
//
//     matched                             5,660  (_merge==3)
//     -----------------------------------------

count if _m!=3
assert `r(N)'==2
count if _m!=3&hhid=="801D010048"|_m!=3&hhid=="809F010189"
assert `r(N)'==2
drop _merge

save data/working/bandungbaseline.dta, replace

