**************************************************
* BANDUNG BASELINE PART II  					 *
**************************************************

***Gets treatment assignment***

use data/raw/baseline_survey_bandung_confidential/b1_vc.dta, clear 

*defines the treatment variables: subsidy
g subsidy = .
replace subsidy = 1 if vc01c == 1 // no subsidy
replace subsidy = 2 if vc01c == 2 // half subsidy
replace subsidy = 3 if vc01c == 3 // half subsidy
replace subsidy = 4 if vc01c == 4 // no inpatient bonus

g nosubsidy    = 0		
replace nosubsidy    = 1 if vc01c == 1
g halfsubsidy  = 0
replace halfsubsidy  = 1 if vc01c == 2
g fullsubsidy  = 0
replace fullsubsidy  = 1 if vc01c == 3
g bonussubsidy = 0
replace bonussubsidy = 1 if vc01c == 4

*renames and labels variables
g voucherid=vc03
ren vc02 kksubsize
ren vc01f kksize 
label define subsidylabel 1 "1. No subsidy"	2 "2. Half subsidy" 3 "3. Full subsidy" 4 "4. No-inpatient bonus"
label value subsidy subsidylabel
label variable kksubsize "Number of hh members covered by subsidy"
label variable kksize "Number of hh members in family card"
label variable voucherid "Voucher code"
label variable subsidy "Subsidy type"

*defines the treatment variables: mandateinfo
g infomandate = 0
replace infomandate = 1 if vc01a2 == 2

*defines the treatment variables: waiting period
g infowaiting = 0
replace infowaiting = 1 if vc01a1 == 2

*defines the treatment variables: onsitereg
g onsitereg = 0
replace onsitereg = 1 if vc01b == 2

keep hhid *subsidy* *info* onsitereg* *id kk* vc03 vc03c vc03c_ot vc03c_1 vc03c_1_ot

tempfile vc
save `vc', replace

***Gets individual characteristics, with PII***

use A:/baseline_survey_bandung/B1_AR1.dta, clear

g hhid=b1_ea+b1_ds+b1_sls2+b1_k
drop  cspro_deleted cspro_sec b1_ea b1_ds b1_sls2 b1_k

**individual characteristics: de-identified personal id

tostring ar00, g(urut)
replace  urut="0"+urut if length(urut)==1
gen	 perid=hhid+urut
drop urut 

**individual characteristics: gender

g sexnik = substr(ar05_b,1,1) //extracting gender information from NIK
replace sexnik = substr(ar06_b,1,1) if ar06_b ~= "" & sexnik == ""
destring sexnik, replace
replace ar08 = 3 if ar08 ==. & sexnik >=4
replace ar08 = 1 if ar08 ==. & sexnik <4

g male = 0
replace male = 1 if ar08 == 1
drop sexnik ar08

**individual characteristics: NIK

generate ar_nik = ar05_a+ar05_b+ar05_c
replace ar_nik = ar06_a+ar06_b+ar06_c if ar_nik == ""

**correction on NIK

drop ar0*_a ar0*_c
label variable ar_nik "Nomor Induk Kependudukan (dari eKTP/KK)"

**individual characteristics: age and date of birth

**age from direct interview
replace ar07_yr = . if ar07_yr > 9000
replace ar07_yr = . if ar07_yr == 1900
replace  ar07_mth = . if ar07_mth > 90
replace  ar07_day = . if ar07_day > 31
replace  ar07_day = . if ar07_day > 30 & inlist(ar07_mth,2,4,6,9,11) 
replace  ar07_day = . if ar07_day > 29 & ar07_mth == 2
replace  ar07_day = . if ar07_day == 29  & ar07_mth == 2 & mod(ar07_yr,4) ~= 0
tostring ar07*, replace force 
replace  ar07_mth = "0"+ar07_mth if length(ar07_mth)==1 & ar07_mth ~= "."
replace  ar07_day = "0"+ar07_day if length(ar07_day)==1 & ar07_day ~= "."
replace  ar07_day = "" if ar07_day == "."
replace  ar07_mth = "" if ar07_mth == "."
replace  ar07_yr = "" if ar07_yr == "."
g dobivw = ar07_day+ar07_mth+substr(ar07_yr,3,2)
replace  dobivw = "" if ar07_yr == "" 
replace  dobivw = "" if (ar07_mth == "" & ar07_day ~= "")
//if no known date for known month, make it the first of the month
replace  dobivw = "01"+dobivw if ar07_day == "" & ar07_mth ~= "" & ar07_yr ~= "" 
//if no known month and day, put in Jan 1st		
replace  dobivw = "0101"+dobivw if ar07_day == "" & ar07_mth == "" & ar07_yr ~= "" 

**age from NIK
g dobfem = ""
replace  dobfem = ar05_b if male == 0 & ar06_b == ""
replace  dobfem = ar06_b if male == 0 & ar05_b == ""
destring dobfem, replace
replace  dobfem = dobfem-400000	
replace dobfem = . if dobfem <10100
tostring dobfem, replace
replace  dobfem = "0"+dobfem if length(dobfem) == 5
g dob = ""
replace  dob = ar05_b if male == 1 & ar06_b == ""
replace  dob = ar06_b if male == 1 & ar05_b == ""
replace  dob = dobfem if male == 0
replace  dob = "" if dob == "."
gen dob_mth = substr(dob,3,2)
gen dob_day = substr(dob,1,2)
destring dob_*, replace force
replace dob     = "" if dob_mth > 12 | dob_mth < 1
replace dob_mth = .  if dob_mth > 12 | dob_mth < 1
replace dob     = "" if dob_day > 31 | dob_day < 1
replace dob_day = .  if dob_day > 31 | dob_day < 1
replace dob     = "" if dob_day > 30 & inlist(dob_mth,2,4,6,9,11) 
replace dob_day = .  if dob_day > 30 & inlist(dob_mth,2,4,6,9,11) 
replace dob_day = .  if dob_day > 29 & dob_mth == 2
replace dob     = dobivw if dob ~= dobivw & dobivw ~= ""

g dateofbirth = date(dob, "DMY", 2016)
format %td dateofbirth
g cdate = c(current_date)
g currentdate = date(cdate, "DMY")
g age = int((currentdate - dateofbirth)/365.25)
format currentdate %td
drop dobfem dob* dobivw ar*_b cdate currentdate ar07*

*individual characteristics: self-reported health
rename ar03 tksehat
replace tksehat = . if tksehat ==9

*dummy for self reported health 
cap drop temp
g temp=0
replace temp = 1 if tksehat == 3 | tksehat == 4
bysort hhid: egen badhealthrt = max(temp)
g badhealth=5-tksehat
bysort hhid: egen badhealthrt_mean=mean(badhealth)
bysort hhid: egen badhealthrt_min=min(badhealth)

ren ar00 urut
ren ar01 nama
ren ar02 edu
ren ar_nik nik 

g hasnik=(nik!="")
bysort hhid: egen hasnikrt=max(hasnik)

drop ar*
drop nama
drop nik 
drop urut

tempfile ar_restricted
save `ar_restricted', replace

***Merges Bandung baseline***

use data/working/bandungbaseline.dta, clear

merge m:1 hhid using `vc'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                             0
//     matched                             5,662  (_merge==3)
//     -----------------------------------------

drop _m

merge 1:m hhid using `ar_restricted'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                             2
//         from master                         2  (_merge==1) no baseline, yes treatment
//         from using                          0  (_merge==2)
//
//     matched                             5,660  (_merge==3)
//     -----------------------------------------

drop _merge

*creates perid for individuals who got treated but did not receive a baseline
replace perid=hhid+"01" if perid==""

*defines the sample for family level outcomes
sort hhid perid
bysort hhid: g n=_n

g rtsample=0
replace rtsample=1 if n==1
drop n
cap drop m_*

tab rtsample

g pilot="BANDUNG"

save data/working/bandungbaseline_with_pii.dta, replace



