**************************************************
* MEDAN BASELINE PART II  				 	     *
**************************************************

***Gets treatment assignment***

use data/raw/baseline_survey_medan_confidential/b1_vc.dta, clear 

*defines the treatment variables: subsidy
gen		subsidy = .
replace subsidy = 0 if vc01c == 1 // no subsidy
replace subsidy = 1 if vc01c == 3 // full subsidy
replace subsidy = 2 if vc01c == 2 // half subsidy
gen 	nosubsidy    = 0		
replace nosubsidy    = 1 if subsidy == 0
gen 	halfsubsidy  = 0
replace halfsubsidy  = 1 if subsidy == 2
gen 	fullsubsidy  = 0
replace fullsubsidy  = 1 if subsidy == 1
ren vc03 voucherid
ren vc02 kksubsize
ren vc01e kkid
ren vc01f kksize 
label define subsidylabel 0 "0. No subsidy"	1 "1. Full subsidy" ///
                          2 "2. Buy-1-get-1-free"
label value subsidy subsidylabel
label variable kkid "Family card number"						  
label variable kksubsize "Number of hh members covered by subsidy"
label variable kksize "Number of hh members in family card"
label variable voucherid "Voucher code"
label variable subsidy "Subsidy type"

*defines the treatment variables: deadline
g 		oneweektmt   = 0
replace oneweektmt   = 1 if vc01d == 1
g 		twoweekstmt  = 0
replace twoweekstmt  = 1 if vc01d == 2
g 		choicetmt    = 0
replace choicetmt    = 1 if vc01d == 3
g 		choicetmt_1w = 0
replace choicetmt_1w = 1 if vc01d == 3 & vc02a == 1
g 		choicetmt_2w = 0
replace choicetmt_2w = 1 if vc01d == 3 & vc02a == 2
g 		onewkdeadline  = 0
replace onewkdeadline  = 1 if vc01d == 1
replace onewkdeadline  = 1 if vc01d == 3 & vc02a == 1
g 		twowkdeadline = 0
replace twowkdeadline = 1 if vc01d == 2
replace twowkdeadline = 1 if vc01d == 3 & vc02a == 2
rename vc01d tmtdeadline

*defines the treatment variables: infoextra
gen 	infoextra    = 0
replace infoextra    = 1 if vc01a == 2

*defines the treatment variables: onsitereg
gen 	onsitereg    = 0
replace onsitereg    = 1 if vc01b == 2

keep hhid *subsidy *deadline *tmt* *infoextra ///
     onsitereg* *id kk* ///
	 vc03c vc03c_ot vc03c_1 vc03c_1_ot
	
tempfile vc
save `vc', replace

***Gets individual characteristics, with PII***

use A:/baseline_survey_medan/b1_ar.dta, clear

**individual characteristics: de-identified personal id
tostring ar00, g(urut)
replace  urut="0"+urut if length(urut)==1
gen	 perid=hhid+urut
drop urut 

**individual characteristics: gender
g sexnik = substr(ar05_b,1,1) //extracting gender information from NIK
replace sexnik = substr(ar06_b,1,1) if ar06_b ~= "" & sexnik == ""
destring sexnik, replace
replace ar08 = 3 if ar08 ==. & sexnik >=4
replace ar08 = 1 if ar08 ==. & sexnik <4

g male = 0
replace male = 1 if ar08 == 1
drop sexnik ar08

**individual characteristics: NIK
generate ar_nik = ar05_a+ar05_b+ar05_c
replace ar_nik = ar06_a+ar06_b+ar06_c if ar_nik == ""

**correction on NIK
drop ar0*_a ar0*_c
label variable ar_nik "Nomor Induk Kependudukan (dari eKTP/KK)"

**individual characteristics: age and date of birth

**age from direct interview
replace ar07_yr = . if ar07_yr > 9000
replace ar07_yr = 1985 if ar07_yr == 1905 & hhid =="912D01008" & ar01a == 1
replace ar07_yr = . if ar07_yr == 1900
replace  ar07_mth = . if ar07_mth > 90
replace  ar07_day = . if ar07_day > 31
replace  ar07_day = . if ar07_day > 30 & inlist(ar07_mth,2,4,6,9,11) 
replace  ar07_day = . if ar07_day > 29 & ar07_mth == 2
replace  ar07_day = . if ar07_day == 29  & ar07_mth == 2 & mod(ar07_yr,4) ~= 0
tostring ar07*, replace force 
replace  ar07_mth = "8"  if hhid == "903D01001" & ar07_mth == "6"
replace  ar07_mth = "1"  if hhid == "910A01063" & ar07_mth == "11"	
replace  ar07_mth = "0"+ar07_mth if length(ar07_mth)==1 & ar07_mth ~= "."
replace  ar07_day = "0"+ar07_day if length(ar07_day)==1 & ar07_day ~= "."
replace  ar07_day = "" if ar07_day == "."
replace  ar07_mth = "" if ar07_mth == "."
replace  ar07_yr = "" if ar07_yr == "."
g dobivw = ar07_day+ar07_mth+substr(ar07_yr,3,2)
replace  dobivw = "" if ar07_yr == "" 
replace  dobivw = "" if (ar07_mth == "" & ar07_day ~= "")
//if no known date for known month, make it the first of the month
replace  dobivw = "01"+dobivw if ar07_day == "" & ar07_mth ~= "" & ar07_yr ~= "" 
//if no known month and day, put in Jan 1st		
replace  dobivw = "0101"+dobivw if ar07_day == "" & ar07_mth == "" & ar07_yr ~= "" 

**age from NIK
g dobfem = ""
replace  dobfem = ar05_b if male == 0 & ar06_b == ""
replace  dobfem = ar06_b if male == 0 & ar05_b == ""
destring dobfem, replace
replace  dobfem = dobfem-400000	
replace dobfem = . if dobfem <10100
tostring dobfem, replace
replace  dobfem = "0"+dobfem if length(dobfem) == 5
g dob = ""
replace  dob = ar05_b if male == 1 & ar06_b == ""
replace  dob = ar06_b if male == 1 & ar05_b == ""
replace  dob = dobfem if male == 0
replace  dob = "" if dob == "."
gen dob_mth = substr(dob,3,2)
gen dob_day = substr(dob,1,2)
destring dob_*, replace force
replace dob     = "" if dob_mth > 12 | dob_mth < 1
replace dob_mth = .  if dob_mth > 12 | dob_mth < 1
replace dob     = "" if dob_day > 31 | dob_day < 1
replace dob_day = .  if dob_day > 31 | dob_day < 1
replace dob     = "" if dob_day > 30 & inlist(dob_mth,2,4,6,9,11) 
replace dob_day = .  if dob_day > 30 & inlist(dob_mth,2,4,6,9,11) 
replace dob_day = .  if dob_day > 29 & dob_mth == 2
replace dob     = dobivw if dob ~= dobivw & dobivw ~= ""

g dateofbirth = date(dob, "DMY", 2016)
format %td dateofbirth
g cdate = c(current_date)
g currentdate = date(cdate, "DMY")
g age = int((currentdate - dateofbirth)/365.25)
format currentdate %td
drop dobfem dob* dobivw ar*_b cdate currentdate ar07*

*individual characteristics: self-reported health
rename ar03 tksehat
replace tksehat = . if tksehat ==9

*dummy for self reported health 
cap drop temp
g temp=0
replace temp = 1 if tksehat == 3 | tksehat == 4
bysort hhid: egen badhealthrt = max(temp)
g badhealth=5-tksehat
bysort hhid: egen badhealthrt_mean=mean(badhealth)
bysort hhid: egen badhealthrt_min=min(badhealth)

ren ar00 urut
ren ar01 nama
ren ar02 edu
ren ar_nik nik 

g hasnik=(nik!="")
bysort hhid: egen hasnikrt=max(hasnik)

drop ar*
drop nik 
drop nama

tempfile ar_restricted
save `ar_restricted', replace

***Merges Medan baseline***

use data/working/medanbaseline.dta, clear

merge m:1 hhid using `vc'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                             0
//     matched                             1,978  (_merge==3)
//     -----------------------------------------

drop _merge

merge 1:m hhid using `ar_restricted'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                            30
//         from master                        30  (_merge==1)
//         from using                          0  (_merge==2)
//
//     matched                             7,923  (_merge==3)
//     -----------------------------------------

drop _merge

*creates perid for individuals who got treated but did not receive a baseline
replace perid=hhid+"01" if perid==""

*defines the sample for family level outcomes
sort hhid perid
bysort hhid: g n=_n

g rtsample=0
replace rtsample=1 if n==1
drop n

g pilot="MEDAN"

save data/working/medanbaseline_with_pii.dta, replace

