***************************************************************
*** Step 1 - Imports and cleans the BPJS claims data		***
***************************************************************
 
***************************************************************
*** HOSPITAL DATA 											***
***************************************************************

*************************************
*** MAY 2017 MATCH			 	  ***
*************************************

use "data/raw/bpjs_confidential/20170512 fktl.dta", clear

rename JnsPelSJP  	jnspelsjp
rename TglDtgSJP  	tgldtgsjp
rename TglPlgSJP  	tglplgsjp
rename JmlHrRawat 	jmlhrrawat
rename KdKlsRwt  	kdklsrwt
rename Los        	los
rename ByVerSJP   	byversjp
rename TglStjKeu  	tglstjkeu
rename BlnLayan   	blnlayan
rename KdKelas    	kdkelas
rename GrupUsia   	grupusia
rename Usia       	usia
rename DiagPrimer 	diagawal
rename NmDiagPrimer nmdiagawal
rename KdInaCBGs  	kdinacbgs
rename NmInaCBG   	nminacbg
rename KCPPK      	kcppk
rename DATI2PPK   	dati2ppk
rename NMPPK      	nmppk
rename NMDATI2PPK 	nmdati2ppk
rename NMPROP     	nmprop

*selects the households from Kota Bandung
g desa=substr(hhid,1,3)
destring desa, replace

g jnspel=""
replace jnspel="RAJAL" if  jnspelsjp=="2"
replace jnspel="RANAP" if  jnspelsjp=="1"

* startdate
cap drop year month day 
g year=regexs(1) if regexm(tgldtgsjp,"([0-9]*)[-]([0-9]*)[-]([0-9]*)")==1
g month=regexs(2) if regexm(tgldtgsjp,"([0-9]*)[-]([0-9]*)[-]([0-9]*)")==1
g day=regexs(3) if regexm(tgldtgsjp,"([0-9]*)[-]([0-9]*)[-]([0-9]*)")==1
g startdate=day+"-"+month+"-"+year

* enddate
cap drop year month day 
g year=regexs(1) if regexm(tglplgsjp,"([0-9]*)[-]([0-9]*)[-]([0-9]*)")==1
g month=regexs(2) if regexm(tglplgsjp,"([0-9]*)[-]([0-9]*)[-]([0-9]*)")==1
g day=regexs(3) if regexm(tglplgsjp,"([0-9]*)[-]([0-9]*)[-]([0-9]*)")==1
g enddate=day+"-"+month+"-"+year

* checks no duplicates
duplicates report // no duplicates once you add precise start and enddate
duplicates report perid membertag jnspel blnlayan byversjp
duplicates report perid membertag jnspel blnlayan byversjp startdate enddate
bysort perid membertag jnspel blnlayan byversjp startdate enddate: g claimid=_n
duplicates report perid membertag jnspel blnlayan byversjp startdate enddate claimid

* corrects variables for merge
g claimdataset="MAY 2017"
drop jnspelsjp jmlhrrawat kdklsrwt los usia kcppk dati2ppk
destring byversjp blnlayan, replace 

*ensures that the membertag refers to the correct nokapst
qui count
local N `r(N)'
ren membertag membertag_20170512
joinby perid membertag_20170512 using data/working/xwalk.dta, unmatched(both)
qui count if _m==3
assert `r(N)'==`N'
keep if _m==3
drop _m

keep perid hhid membertag_final claimid jnspel blnlayan byversjp startdate enddate claimdataset nmdiagawal kdinacbgs

tempfile claims_may17
save `claims_may17', replace

*************************************
*** JUL 2018 MATCH			 	  ***
*************************************

use "data/raw/bpjs_confidential/20180816 fktl.dta", clear

rename JnsPelSJP  	jnspelsjp
rename TglDtgSJP  	tgldtgsjp
rename TglPlgSJP  	tglplgsjp
// rename JmlHrRawat 	jmlhrrawat
rename KlsRawat  	kdklsrwt
// rename Los        	los
rename ByVerSJP   	byversjp
rename TglStjKeu  	tglstjkeu
// rename BlnLayan   	blnlayan
// rename KdKelas    	kdkelas
// rename GrupUsia   	grupusia
// rename Usia       	usia
rename KodeDiagPrimer 	diagawal
rename NmDiagPrimer nmdiagawal
rename KdInaCbgs  	kdinacbgs
rename NmInaCbgs   	nminacbg
// rename KCPPK      	kcppk
// rename DATI2PPK   	dati2ppk
// rename NMPPK      	nmppk
// rename NMDATI2PPK 	nmdati2ppk
// rename NMPROP     	nmprop

*selects the households from Kota Medan
g desa=substr(hhid,1,3)
destring desa, replace
drop if inlist(desa,991,992,993)

g jnspel=""
replace jnspel="RAJAL" if  jnspelsjp=="2"
replace jnspel="RANAP" if  jnspelsjp=="1"

* startdate
cap drop year month day 
g year=regexs(1) if regexm(tgldtgsjp,"([0-9]*)[-]([0-9]*)[-]([0-9]*)")==1
g month=regexs(2) if regexm(tgldtgsjp,"([0-9]*)[-]([0-9]*)[-]([0-9]*)")==1
g day=regexs(3) if regexm(tgldtgsjp,"([0-9]*)[-]([0-9]*)[-]([0-9]*)")==1
g startdate=day+"-"+month+"-"+year

* enddate
cap drop year month day 
g year=regexs(1) if regexm(tglplgsjp,"([0-9]*)[-]([0-9]*)[-]([0-9]*)")==1
g month=regexs(2) if regexm(tglplgsjp,"([0-9]*)[-]([0-9]*)[-]([0-9]*)")==1
g day=regexs(3) if regexm(tglplgsjp,"([0-9]*)[-]([0-9]*)[-]([0-9]*)")==1
g enddate=day+"-"+month+"-"+year

* checks no duplicates
duplicates report // no duplicates once you add precise start and enddate
duplicates report perid membertag jnspel blnlayan byversjp
duplicates report perid membertag jnspel blnlayan byversjp startdate enddate
bysort perid membertag jnspel blnlayan byversjp startdate enddate: g claimid=_n
duplicates report perid membertag jnspel blnlayan byversjp startdate enddate claimid

* corrects variables for merge
g claimdataset="AUG 2018"
destring byversjp blnlayan, replace 

*ensures that the membertag refers to the correct nokapst
qui count
local N `r(N)'
ren membertag membertag_20180816
joinby perid membertag_20180816 using data/working/xwalk.dta, unmatched(both)
qui count if _m==3
assert `r(N)'==`N'
keep if _m==3
drop _m

keep perid hhid membertag_final jnspel blnlayan byversjp startdate enddate claimdataset nmdiagawal claimid

merge 1:1 perid membertag_final claimid jnspel blnlayan byversjp startdate enddate using `claims_may17'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                         6,700
//         from master                     6,698  (_merge==1)
//         from using                          2  (_merge==2)
//
//     matched                             4,461  (_merge==3)
//     -----------------------------------------

drop _m

g dataset="HOSPITAL"

tempfile hospitalclaims
save `hospitalclaims', replace

***************************************************************
*** HEALTH CLINIC DATA										***
***************************************************************

*************************************
*** MAY 2017 MATCH			 	  ***
*************************************

use "data/raw/bpjs_confidential/20170512 fktp.dta", clear

*selects the households from Kota Bandung
g desa=substr(hhid,1,3)
destring desa, replace
drop if inlist(desa,991,992,993)

g jnspel=""
replace jnspel="RAJAL" 

*for the health clinic data startdate = enddate
* startdate
cap drop year month day 
g year=regexs(1) if regexm(tgl_kunjungan,"([0-9]*)[-]([0-9]*)[-]([0-9]*)")==1
g month=regexs(2) if regexm(tgl_kunjungan,"([0-9]*)[-]([0-9]*)[-]([0-9]*)")==1
g day=regexs(3) if regexm(tgl_kunjungan,"([0-9]*)[-]([0-9]*)[-]([0-9]*)")==1
g startdate=day+"-"+month+"-"+year
g enddate=day+"-"+month+"-"+year

* checks for duplicates and creates a unique identifier for claim
duplicates report
duplicates report perid membertag blnlayan startdate enddate
bysort perid membertag blnlayan startdate enddate: g claimid=_n
duplicates report perid membertag blnlayan startdate enddate claimid

*ensures that the membertag refers to the correct nokapst
qui count
local N `r(N)'
ren membertag membertag_20170512
joinby perid membertag_20170512 using data/working/xwalk.dta, unmatched(both)
qui count if _m==3
assert `r(N)'==`N'
keep if _m==3
drop _m

* keeps the correct variables
keep perid membertag_final claimid hhid jnspel blnlayan startdate enddate description

tempfile claims_may17
save `claims_may17', replace

*************************************
*** JUL 2018 MATCH			 	  ***
*************************************

use "data/raw/bpjs_confidential/20180816 fktp.dta", clear

g desa=substr(hhid,1,3)
destring desa, replace
drop if inlist(desa,991,992,993)

g jnspel=""
replace jnspel="RAJAL" 

ren TglKunjungan tgl_kunjungan
ren NmDiag description

*for the health clinic data startdate = enddate
* startdate
cap drop year month day 
g year=regexs(1) if regexm(tgl_kunjungan,"([0-9]*)[-]([0-9]*)[-]([0-9]*)")==1
g month=regexs(2) if regexm(tgl_kunjungan,"([0-9]*)[-]([0-9]*)[-]([0-9]*)")==1
g day=regexs(3) if regexm(tgl_kunjungan,"([0-9]*)[-]([0-9]*)[-]([0-9]*)")==1
g startdate=day+"-"+month+"-"+year
g enddate=day+"-"+month+"-"+year

* checks for duplicates and creates a unique identifier for claim
duplicates report
duplicates report perid membertag blnlayan startdate enddate
bysort perid membertag blnlayan startdate enddate: g claimid=_n
duplicates report perid membertag blnlayan startdate enddate claimid

g claimdataset="JUL 2018"

*ensures that the membertag refers to the correct nokapst
qui count
local N `r(N)'
ren membertag membertag_20180816
joinby perid membertag_20180816 using data/working/xwalk.dta, unmatched(both)
qui count if _m==3
assert `r(N)'==`N'
keep if _m==3
drop _m

* keeps the correct variables
keep perid membertag_final claimid hhid jnspel blnlayan startdate enddate description

merge 1:1 perid membertag_final claimid jnspel blnlayan startdate enddate using `claims_may17'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                         8,339
//         from master                     8,271  (_merge==1)
//         from using                         68  (_merge==2)
//
//     matched                             6,855  (_merge==3)
//     -----------------------------------------

drop _m

g dataset="HEALTHCLINIC"

destring blnlayan, replace

***************************************************************
*** APPENDS DATA											***
***************************************************************

append using `hospitalclaims'

replace description=nmdiagawal if description==""&nmdiagawal!=""
mdesc description

* startdate and enddate in the right format
cap drop year month day
cap drop temp
ren startdate temp
replace temp=regexs(2) if regexm(temp,"([0])([0-9][-][0-9]*[-][0-9]*)")==1
replace temp=regexs(1)+regexs(2)+regexs(4) if regexm(temp,"([0-9]*)([-])([0])([0-9]*[-][0-9]*)")==1
g startdate=date(temp,"DMY")
format %td startdate 

cap drop year month day
cap drop temp
ren enddate temp
replace temp=regexs(2) if regexm(temp,"([0])([0-9][-][0-9]*[-][0-9]*)")==1
replace temp=regexs(1)+regexs(2)+regexs(4) if regexm(temp,"([0-9]*)([-])([0])([0-9]*[-][0-9]*)")==1
g enddate=date(temp,"DMY")
format %td enddate 

save data/working/claims.dta, replace

***************************************************************
*** Step 2 - Cleans the claims data							***
***************************************************************

preserve
use data/working/baseline_with_payment.dta, clear
keep if rtsample==1
keep hhid firstsignuprt* offerdate enroll* signupdate enroll_ST membership  restrictedsample membership offerdate nosubsidy halfsubsidy fullsubsidy bonussubsidy onsite
tempfile signupdate
save `signupdate'
restore

use data/working/claims.dta, clear

merge m:1 hhid  using `signupdate'


//     Result                           # of obs.
//     -----------------------------------------
//     not matched                         5,442
//         from master                         0  (_merge==1)
//         from using                      5,442  (_merge==2)
//
//     matched                            26,355  (_merge==3)
//     -----------------------------------------

count if _m==1
assert `r(N)'==0
keep if _m==3

* checks that I have the signupdate for all enrolled
count if _m==3&firstsignuprt==.
local nofirstsignuprt=`r(N)'
count if _m==3&firstsignuprt==.&enroll==0
assert `r(N)'==`nofirstsignuprt'

drop if enroll_2yrs==0
drop _m

* early claim
* we only use the claims after our study period but create dummmy to keep track of hhid w/ pre-study claim
g earlyclaim=1-(startdate>firstsignuprt&firstsignuprt!=.)
drop if earlyclaim==1
drop earlyclaim

* outpatient versus inpatient
g servtype=""
replace servtype="OUT" if jnspel=="RAJAL"
replace servtype="IN" if jnspel=="RANAP"

destring  byversjp, replace

*******************************************
* Defines chronic claims using ICD10 data *
*******************************************

// CHRONIC CLAIMS 
ren description description_orig
g description=lower(strtrim(description_orig))
replace description=subinstr(description,",","",.)
replace description=subinstr(description,"'","",.)
replace description=subinstr(description,"(","",.)
replace description=subinstr(description,")","",.)
replace description=subinstr(description,"[","",.)
replace description=subinstr(description,"]","",.)

// 1. matches ICD-10:2008 codes to diagnosis

// gets ICD-10:2008 codes
preserve
import excel "data/raw/icd10_confidential/ICD10_2008_codes_full.xlsx", sheet("Sheet1") clear all

g code=regexs(1) 				 if regexm(A,"([A-Z][0-9]*)")
replace code=regexs(1)+regexs(2) if regexm(A,"([A-Z][0-9]*)[\.]([0-9*])")
replace code=regexs(1)+"-"+regexs(2) if regexm(A,"([A-Z][0-9]*)[-]([A-Z][0-9]*)")
drop if length(code)==1

g description=lower(substr(A,length(code)+2,length(A)))
replace description=subinstr(description,",","",.)
replace description=subinstr(description,"'","",.)
replace description=subinstr(description,"(","",.)
replace description=subinstr(description,")","",.)
replace description=subinstr(description,":","",.)
replace description=subinstr(description,"[","",.)
replace description=subinstr(description,"]","",.)
replace description=regexs(0) if regexm(description,"([a-z0-9 \-]+)")
replace description=strtrim(description)

keep code description

// drops duplicates
bysort description: g n=_n
keep if n==1

tempfile icd10_codes
save `icd10_codes', replace
restore

// gets icd10cm codes that were handchecked
preserve
import excel "data/raw/icd10_confidential/ICD10_2008_codes_full_checks.xlsx", sheet("Sheet1") clear all first

ren code code_checked

tempfile icd10_codes_checked
save `icd10_codes_checked', replace
restore

// merges in codes
merge m:1 description using `icd10_codes'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                         9,831
//         from master                       157  (_merge==1)
//         from using                      9,674  (_merge==2)
//
//     matched                               897  (_merge==3)
//     -----------------------------------------

drop if _m==2
drop _m

merge m:1 description_orig using `icd10_codes_checked'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                           901
//         from master                       899  (_merge==1)
//         from using                          2  (_merge==2)
//
//     matched                               155  (_merge==3)
//     -----------------------------------------

drop if _m==2
drop _m

replace code=code_checked if code==""&code_checked!=""&code_checked!="N/A"
ren code icd10cmcode

// code_class
g code_class=substr(icd10cmcode,1,3)

// 2. gets information on whether chrnonic
preserve
use data/raw/icd10_confidential/cci_icd10cm_2018_1.dta, clear 

// description
g description=lower(strtrim(icd10cmcodedescription))
replace description=lower(strtrim(description))
replace description=subinstr(description,",","",.)
replace description=subinstr(description,"'","",.)
replace description=subinstr(description,"(","",.)
replace description=subinstr(description,")","",.)
replace description=subinstr(description,"[","",.)
replace description=subinstr(description,"]","",.)

// code
replace icd10cmcode=subinstr(icd10cmcode,"'","",.)

// code_class
g code_class=substr(icd10cmcode,1,3)

// chronic indicator
replace chronicindicator=subinstr(chronicindicator,"'","",.)
destring chronicindicator, replace

// creates chronic classification by code_class
bysort code_class: egen chronic_mean_by_code_class=mean(chronicindicator)
g chronic_code_class=(chronic_mean_by_code_class>=0.75&chronic_mean_by_code_class!=.)

bysort code_class: g n=_n
keep if n==1

keep code_class chronic_code_class chronic_mean_by_code_class

tempfile ICD10CM_chronic
save `ICD10CM_chronic', replace
restore

// 3. merges in information

// handchecks
replace code_class="A15" if code_class=="A16"
replace code_class="A13" if code_class=="E14"
replace code_class="K64" if code_class=="I84"
replace code_class="J45" if code_class=="J46"
replace code_class="M26" if code_class=="K07"
replace code_class="M27" if code_class=="K10"
replace code_class="I96" if code_class=="R02"
replace code_class="O09" if code_class=="Z35"

merge m:1 code_class using `ICD10CM_chronic'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                         1,439
//         from master                        23  (_merge==1)
//         from using                      1,416  (_merge==2)
//
//     matched                             1,031  (_merge==3)
//     -----------------------------------------

drop if _m==2
drop _m

replace chronic_code_class=0 if chronic_code_class==.

*date of first claim ever
bysort perid membertag_final: egen firstclaimind=min(startdate)
format %td firstclaimind 

// saves data that will be needed to create figure 6 
save data/working/claims_cleaned_all.dta, replace


*******************************************
* Creates claims by calendar month		  *
*******************************************

preserve
g yearmonthclaim = ym(year(startdate),month(startdate)) 
format %tm yearmonthclaim

cap drop *ind* 

* creates the variables
g outind=(servtype=="OUT")
g outindnum=outind

g outhospind=(servtype=="OUT"&dataset=="HOSPITAL")
g outhospindnum=outhospind

g inpind=(servtype=="IN")
g inpindnum=inpind

g chronicind=chronic_code_class
g chronicindnum=chronicind

g outhospindtotvalue=0
replace outhospindtotvalue=byversjp if servtype=="OUT"&dataset=="HOSPITAL"
g inpindtotvalue=0
replace inpindtotvalue=byversjp if servtype=="IN"

g membershipok=(membership=="PEKERJA BUKAN PENERIMA UPAH")
g signupdatesame=(signupdate==firstsignuprt)

* collapses to claims by calendar month
collapse (max) membershipok signupdatesame outind outhospind inpind chronicind (sum) outindnum outhospindnum inpindnum outhospindtotvalue inpindtotvalue chronicindnum (min) startdate, by(perid membertag_final yearmonthclaim)

g yearmonth=yearmonthclaim
format %tm yearmonth

merge 1:1 perid membertag_final yearmonth using data/working/enrollment_month.dta

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                        68,740
//         from master                       580  (_merge==1)	MONTHS IN WHICH YOU HAVE A CLAIM BUT NO PAYMENT
//         from using                     68,160  (_merge==2)	MONTHS IN WHICH YOU HAVE PAYMENT AND NO CLAIMS
//
//     matched                             4,349  (_merge==3)	MONTHS IN WHICH YOU HAVE BOTH
//     -----------------------------------------

// 580 INDIVIDUAL/MONTHS IN WHICH THERE IS A CLAIM BUT NO PAYMENT
// 114 INDIVIDUALS HAVE A MONTH IN WHICH THEY HAVE A CLAIM BUT NO PAYMENT
// 106 OF THESE INDIVIDUALS NEVER SHOW UP IN THE PAYMENT DATA
// 49 OF THESE INDIVIDUALS SHOULD NOT SHOW UP IN THE PAYMENT DATA
// BUT 57 HAVE CORRECT MEMBERSHIP AND SIGNUPDATE, SO THEY SHOULD: THEY ARE PART OF THE NEVER PAID GROUP
bysort perid membertag_final: g n=_n
bysort perid membertag_final: egen everpaid=max((_m==2|_m==3))
bysort perid membertag_final: egen correct=max(membershipok==1|signupdatesame==1)
tab _m if n==1
tab everpaid if _m==1&n==1, m
tab everpaid correct if _m==1&n==1, m 
cap drop temp
g temp=outindnum+inpindnum
bysort perid membertag_final: egen totclaims=total(temp)
su totclaims if _m==1&n==1&correct==1&everpaid==0, d

// THE REMAINING 9 INDIVIDUALS DO SHOW UP IN THE PAYMENT DATA, BUT FOR OTHER MONTHS
// MAJORITY OF CLAIMS (~50%) ARE IN THE IMMEDIATE NEXT MONTH AFTER THEY STOP PAYING
// LOADS THE CLAIMS IN THE MONTH IMMEDIATELY AFTER THEY STOP PAYING ONTO THE LAST MONTH
cap drop temp
g temp1=lastmonthpaid if everpaid==1
g temp2=em_offer if yearmonth==lastmonthpaid
g temp3=em_signup if yearmonth==lastmonthpaid
bysort perid membertag_final: egen lastmonthind=max(temp1)
bysort perid membertag_final: egen lastenrollmonthind=max(temp2)
bysort perid membertag_final: egen lastenrollmonthind_signup=max(temp3)
g monthsafter=yearmonth-lastmonthind
tab monthsafter if _m==1
replace em_offer=lastenrollmonthind if monthsafter==1&_m==1&em_offer==.
replace em_signup=lastenrollmonthind_signup if monthsafter==1&_m==1&em_signup==.

// KEEPS TRACK OF CLAIMS IN MONTHS FOR WHICH NO PREMIUM PAID BY CREATING ENROLLMONTH == 99
drop if _m==2
replace em_offer=99 if _m==1&monthsafter>1 // already counting the claims one month after they start paying
replace em_signup=99 if _m==1&monthsafter>1 // already counting the claims one month after they start paying
drop if em_offer==.|em_signup==.

drop _m
drop yearmonthclaim yearmonth lastmonthpaid
g em_signup_v2=em_signup

collapse (max) em_signup outind outhospind inpind chronicind (sum) outindnum outhospindnum inpindnum chronicindnum outhospindtotvalue inpindtotvalue (min) em_signup_v2 startdate, by(perid membertag_final em_offer)

count if em_signup_v2!=em_signup
assert `r(N)'==0
drop em_signup_v2

* individual level claims variables by MONTH SINCE SIGNUP
forvalues month=1(1)24 {
	foreach var of varlist outind outhospind inpind chronicind outindnum outhospindnum inpindnum chronicindnum outhospindtotvalue inpindtotvalue startdate {
		cap drop temp
		g temp=`var' if em_signup==`month'
		bysort perid membertag_final: egen `var'_signup`month'=max(`var'*(em_signup==`month')) // just keeping the value for that month
		}
	}
drop em_signup
drop temp
	
reshape wide outind outhospind inpind chronicind outindnum outhospindnum inpindnum chronicindnum outhospindtotvalue inpindtotvalue startdate, i(perid membertag_final) j(em_offer)

************************************
* Claims by month since offer date *
************************************

// BY MONTH
forvalues month=1(1)24 {
	g anyind`month'=(outind`month'==1|inpind`month'==1)
	g anyhospind`month'=(outhospind`month'==1|inpind`month'==1)
	g anyindnum`month'=outindnum`month'+inpindnum`month'
	g anyhospindnum`month'=outhospindnum`month'+inpindnum`month'
	g anyindtotvalue`month'=outhospindtotvalue`month'+inpindtotvalue`month'
	}

// MONTHS 1 to 13 SINCE OFFER DATE
foreach stub in any out outhosp inp chronic anyhosp {
	egen `stub'indnum_offer_1to12=rsum(`stub'indnum1 `stub'indnum2 `stub'indnum3 `stub'indnum4 `stub'indnum5 `stub'indnum6 `stub'indnum7 `stub'indnum8 `stub'indnum9 `stub'indnum10 `stub'indnum11 `stub'indnum12)
	g `stub'ind_offer_1to12=(`stub'indnum_offer_1to12!=0&`stub'indnum_offer_1to12!=.)
	if "`stub'"=="any"|"`stub'"=="inp"|"`stub'"=="outhosp" {
		egen `stub'indtotvalue_offer_1to12=rsum(`stub'indtotvalue1 `stub'indtotvalue2 `stub'indtotvalue3 `stub'indtotvalue4 `stub'indtotvalue5 `stub'indtotvalue6 `stub'indtotvalue7 `stub'indtotvalue8 `stub'indtotvalue9 `stub'indtotvalue10 `stub'indtotvalue11 `stub'indtotvalue12)
		}
	}
egen firstclaimind_offer_1to12=rowmin(startdate1 startdate2 startdate3 startdate4 startdate5 startdate6 startdate7 startdate8 startdate9 startdate10 startdate11 startdate12)
format %td firstclaimind_offer_1to12

// MONTHS 13 TO 20 SINCE OFFER DATE
foreach stub in any out outhosp inp chronic anyhosp {
	egen `stub'indnum_offer_13to20=rsum(`stub'indnum13 `stub'indnum14 `stub'indnum15 `stub'indnum16 `stub'indnum17 `stub'indnum18 `stub'indnum19 `stub'indnum20)
	g `stub'ind_offer_13to20=(`stub'indnum_offer_13to20!=0&`stub'indnum_offer_13to20!=.)
	if "`stub'"=="any"|"`stub'"=="inp"|"`stub'"=="outhosp" {
		egen `stub'indtotvalue_offer_13to20=rsum(`stub'indtotvalue13 `stub'indtotvalue14 `stub'indtotvalue15 `stub'indtotvalue16 `stub'indtotvalue17 `stub'indtotvalue18 `stub'indtotvalue19 `stub'indtotvalue20)
		}
	}


*************************************
* Claims by month since signup date *
*************************************

// BY MONTH
forvalues month=1(1)24 {
	g anyind_signup`month'=(outind_signup`month'==1|inpind_signup`month'==1)
	g anyhospind_signup`month'=(outhospind_signup`month'==1|inpind_signup`month'==1)
	g anyindnum_signup`month'=outindnum_signup`month'+inpindnum_signup`month'
	g anyhospindnum_signup`month'=outhospindnum_signup`month'+inpindnum_signup`month'
	g anyindtotvalue_signup`month'=outhospindtotvalue_signup`month'+inpindtotvalue_signup`month'
	replace startdate_signup`month'=. if startdate_signup`month'==0
	}

// CLAIMS BY MONTH SINCE SIGNUP: 1to3, 4to12, 1to12, 13to24	

// 1to12	
foreach stub in any out outhosp inp chronic anyhosp {
	egen `stub'indnum_signup_1to12=rsum(`stub'indnum_signup1 `stub'indnum_signup2 `stub'indnum_signup3 `stub'indnum_signup4 `stub'indnum_signup5 `stub'indnum_signup6 `stub'indnum_signup7 `stub'indnum_signup8 `stub'indnum_signup9 `stub'indnum_signup10 `stub'indnum_signup11 `stub'indnum_signup12)
	g `stub'ind_signup_1to12=(`stub'indnum_signup_1to12!=0&`stub'indnum_signup_1to12!=.)
	if "`stub'"=="any"|"`stub'"=="inp"|"`stub'"=="outhosp" {
		egen `stub'indtotvalue_signup_1to12=rsum(`stub'indtotvalue_signup1 `stub'indtotvalue_signup2 `stub'indtotvalue_signup3 `stub'indtotvalue_signup4 `stub'indtotvalue_signup5 `stub'indtotvalue_signup6 `stub'indtotvalue_signup7 `stub'indtotvalue_signup8 `stub'indtotvalue_signup9 `stub'indtotvalue_signup10 `stub'indtotvalue_signup11 `stub'indtotvalue_signup12)
		}
	}
egen firstclaimind_signup_1to12=rowmin(startdate_signup1 startdate_signup2 startdate_signup3 startdate_signup4 startdate_signup5 startdate_signup6 startdate_signup7 startdate_signup8 startdate_signup9 startdate_signup10 startdate_signup11 startdate_signup12)
format %td firstclaimind_signup_1to12

// 13to20	
foreach stub in any out outhosp inp chronic anyhosp {
	egen `stub'indnum_signup_13to20=rsum(`stub'indnum_signup13 `stub'indnum_signup14 `stub'indnum_signup15 `stub'indnum_signup16 `stub'indnum_signup17 `stub'indnum_signup18 `stub'indnum_signup19 `stub'indnum_signup20)
	g `stub'ind_signup_13to20=(`stub'indnum_signup_13to20!=0&`stub'indnum_signup_13to20!=.)
	if "`stub'"=="any"|"`stub'"=="inp"|"`stub'"=="outhosp" {
		egen `stub'indtotvalue_signup_13to20=rsum(`stub'indtotvalue_signup13 `stub'indtotvalue_signup14 `stub'indtotvalue_signup15 `stub'indtotvalue_signup16 `stub'indtotvalue_signup17 `stub'indtotvalue_signup18 `stub'indtotvalue_signup19 `stub'indtotvalue_signup20)
		}
	}

tempfile monthlyclaims
save `monthlyclaims', replace
restore

cap drop n
bysort perid membertag_final: g n=_n
keep if n==1
keep hhid perid membertag_final firstclaimind

merge 1:1 perid membertag_final using `monthlyclaims'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                             0
//     matched                             1,199  (_merge==3)
//     -----------------------------------------

drop _m

forvalues x=1(1)20 {
	bysort hhid: egen anyrtotvalue_offer_`x'=total(anyindtotvalue`x')
	}

drop *ind? *ind??
drop *indnum? *indnum?? 
drop *indtotvalue? *indtotvalue?? 
drop startdate? startdate??

save data/working/claims_cleaned.dta, replace

