***************************************
*** STEP 1: BPJS ENROLLMENT DATA   ***
***************************************

***************************************
*** Imports the enrollment datasets ***
***************************************

foreach extract in SEP15 DEC15 APR16 JUN16 AUG16 SEP16 OCT16 NOV16 APR17 MAY17 JUL18 AUG18 {
	
	// fname
	if "`extract'"=="SEP15"				local fnamein	"20150903 kepesertaan_RS"
	else if "`extract'"=="DEC15"		local fnamein	"20151211 kepesertaan_RS"
	else if "`extract'"=="APR16"		local fnamein	"20160411 kepesertaan_RS"
	else if "`extract'"=="JUN16"		local fnamein	"20160610 kepesertaan_RS"
	else if "`extract'"=="AUG16"		local fnamein	"20160824 kepesertaan_RS"
	else if "`extract'"=="SEP16"		local fnamein	"20160921 kepesertaan_RS"
	else if "`extract'"=="OCT16"		local fnamein	"20161020 kepesertaan_RS"
	else if "`extract'"=="NOV16"		local fnamein	"20161121 kepesertaan"
	else if "`extract'"=="APR17"		local fnamein	"20170428 kepesertaan"
	else if "`extract'"=="MAY17"		local fnamein	"20170512 kepesertaan"
	else if "`extract'"=="JUL18"		local fnamein	"20180716 kepesertaan"
	else if "`extract'"=="AUG18"		local fnamein	"20180816 kepesertaan"
	else BREAK
	
	// date
	if "`extract'"=="SEP15"				local date		"20150903"
	else if "`extract'"=="DEC15"		local date		"20151211"
	else if "`extract'"=="APR16"		local date		"20160411"
	else if "`extract'"=="JUN16"		local date		"20160610"
	else if "`extract'"=="AUG16"		local date		"20160824"
	else if "`extract'"=="SEP16"		local date		"20160921"
	else if "`extract'"=="OCT16"		local date		"20161020"
	else if "`extract'"=="NOV16"		local date		"20161121"
	else if "`extract'"=="APR17"		local date		"20170428"
	else if "`extract'"=="MAY17"		local date		"20170512"
	else if "`extract'"=="JUL18"		local date		"20180716"
	else if "`extract'"=="AUG18"		local date		"20180816"
	else BREAK

	use "data/raw/bpjs_confidential/`fnamein'.dta", clear
	
	* drops Gresik
	g desa=substr(hhid,1,3)
	destring desa, replace
	drop if inlist(desa,991,992,993)

	* membership
	ren kelompok membership_`extract'

	* creates signupdate variables
	if "`extract'"=="JUL18"|"`extract'"=="AUG18"	generate double tmttime = clock(tmt, "YMD")
	else											generate double tmttime = clock(tmt, "YMDhms")
	generate signupdate_`extract' = dofc(tmttime)
	format   %td signupdate_`extract'
	qui count if signupdate_`extract'==.
	local missing = `r(N)'
	qui count
	assert `r(N)' != `missing'

	*ensures that the membertag refers to the correct nokapst
	qui count
	local N `r(N)'
	ren membertag membertag_`date'
	merge 1:m perid membertag_`date' using data/working/xwalk.dta
	qui count if _m==3
	assert `r(N)'==`N'
	keep if _m==3
	drop _m

	ren dob_admin dob_admin_`extract'
	ren kdkelas kdkelas_`extract'
	ren dup_nokapst dup_nokapst_`extract'
	
	keep perid membertag_final *`extract'
	
	g enrolldataset="`extract'"
	
	tempfile enroll_`extract'
	save `enroll_`extract'', replace

	}

***************************************
*** Merges the enrollment datasets  ***
***************************************
		
local iter=1
pause off
foreach extract in SEP15 DEC15 APR16 JUN16 AUG16 SEP16 OCT16 NOV16 APR17 MAY17 JUL18 AUG18 {
	
	if `iter'==1 use `enroll_`extract'', clear
	if `iter'!=1 merge 1:1 perid membertag_final using `enroll_`extract''
	
	cap drop _m
	local ++iter
	pause
	}
	
// ADDS DATE OF BIRTH FROM BASELINE
preserve
use data/working/medanbaseline_with_pii.dta, clear 
append using data/working/bandungbaseline_with_pii.dta

keep perid dateofbirth
ren dateofbirth dob_baseline

tempfile dob
save `dob'
restore

cap drop dob_baseline

merge m:1 perid using `dob'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                        17,134
//         from master                         2  (_merge==1)
//         from using                     17,132  (_merge==2)
//
//     matched                            12,094  (_merge==3)
//     -----------------------------------------

qui count if _m==1&perid!="901C0103406"&_m==1&perid!="903A0104004"
assert `r(N)'==0
drop if _m==2
drop _m

// DROPS INDIVIDUALS NOT PART OF THE BASELINE
drop if perid=="901C0103406"|perid=="903A0104004" 
	

***********************************
***  CLEANS THE ENROLLMENT DATA ***
***********************************

// saves copy of full enrollment data (needed later)
save data/working/enrollmentBPJS_FULL.dta, replace

keep perid membertag_final membership* signupdate* dob_admin* dob_baseline dup_nokapst* enrolldataset
order perid membertag_final

// MEMBERSHIP and SIGNUPDATE
// USES INFORMATION CONTAINED IN THE FIRST EXTRACT IN WHICH INDIVIDUAL HAS A MATCH
// EFFECTIVELY ONLY USES NEW NIK MATCHES
g membership=""
g signupdate=.
foreach extract in SEP15 DEC15 APR16 JUN16 AUG16 SEP16 OCT16 NOV16 APR17 MAY17 JUL18 AUG18 {
	replace membership=membership_`extract' if membership==""&membership_`extract'!=""
	replace signupdate=signupdate_`extract' if signupdate==.&signupdate_`extract'!=.
	}
format %td signupdate

// ADMIN DATE OF BIRTH CHANGES
// USES INFORMATION CONTAINED IN ANY EXTRACT (SAY -- THEY MAKE A CORRECTION)
g dobok_exact=0
g dobok_year=0
g dobok=0
foreach extract in SEP15 DEC15 APR16 JUN16 AUG16 SEP16 OCT16 NOV16 APR17 MAY17 JUL18 AUG18 {
	replace dobok_exact=1 	if dob_admin_`extract'==dob_baseline
	replace dobok_year=1 	if year(dob_admin_`extract')==year(dob_baseline)
	replace dobok=1			if abs(year(dob_admin_`extract')-year(dob_baseline))<=1
	}
	
// DUPLICATES NOKAPST
// USES MANUALLY CHECKED NIK TO DROP INDIVIDUALS WHO ARE MATCHED BECAUSE THEY REPORT THE WRONG NIK
g todrop=0
replace todrop=1 if perid=="904A0106702"&membertag==1
replace todrop=1 if perid=="904C0101602"&membertag==1
replace todrop=1 if perid=="904D0100402"&membertag==1
replace todrop=1 if perid=="904G0104006"&membertag==1
replace todrop=1 if perid=="905F0107202"&membertag==1
replace todrop=1 if perid=="905G0100104"&membertag==1
replace todrop=1 if perid=="908C0113302"&membertag==1
replace todrop=1 if perid=="909E0106402"&membertag==1
replace todrop=1 if perid=="910B0105003"&membertag==1

// DUPLICATES PERID
cap drop dup_perid*
duplicates tag perid, g(dup_perid_raw) 
tab dup_perid_raw

// dup_perid_r |
//          aw |      Freq.     Percent        Cum.
// ------------+-----------------------------------
//           0 |     10,980       90.79       90.79
//           1 |      1,084        8.96       99.75
//           2 |         30        0.25      100.00
// ------------+-----------------------------------
//       Total |     12,094      100.00

// if only one observation has date of birth match the one from nik; keep that observation
// if only one observation has year of birth match the one from nik; keep that observation
bysort perid: egen obs_dobok=sum(dobok_exact)
bysort perid: egen obs_dobok_year=sum(dobok_year)      

// # of observations with duplicate perid
duplicates report perid
duplicates report perid if dobok==1
duplicates report perid if dobok_year==1

//
tab obs_dobok if dup_perid_raw!=0	 		
tab obs_dobok_year if dup_perid_raw!=0	

replace todrop=1 if dup_perid==1&todrop==0&obs_dobok==1&dobok_exact==0   // 243 cases resolved by this step
replace todrop=1 if dup_perid==1&todrop==0&obs_dobok_year==1&dobok_year==0 // 4 cases resolved by this step
replace todrop=1 if dup_perid==2&todrop==0&obs_dobok==1&dobok_exact==0|dup_perid==2&todrop==0&obs_dobok==2&dobok_exact==0   // 9 case resolved by this step
replace todrop=1 if dup_perid==2&todrop==0&obs_dobok_year==1&dobok_year==0|dup_perid==2&todrop==0&obs_dobok_year==2&dobok_year==0  // 0 cases resolved by this step

// DROP INDIVIDUALS WITH DUPLICATES
drop if todrop==1

// BUT WE STILL HAVE 126 PERID DUPLICATES
// SOLUTION: KEEP THEM BOTH
// THINK OF DUPLICATES AS SOMEONE ELSE IN THE HOUSEHOLD WHO ENROLLED WITH THE SAME NIK
duplicates tag perid, gen(dup_perid)
duplicates report perid 

// DOUBLE CHECKS NO DUPLICATES
duplicates report perid membertag_final

// RELEVANT VARIABLE TO KEEP TRACK OF DUP_NOKAPST IS THE ONE FROM AUG18 (MOST EXHAUSTIVE)
// GENERALLY SIMILAR; A FEW CASES HAVE BEEN CORRECTED OVER TIME SO NO LONGER DUPLICATES
// DROPS INDIVIDUALS WHO HAVE A NOKAPST DUPLICATE
g dup_nokapst=dup_nokapst_AUG18
drop if dup_nokapst==1

// KEEPS THE RELEVANT VARIABLES
keep perid membertag_final* membership signupdate dobok dobok_year dobok_exact dup_perid dup_perid_raw enrolldataset

g pilot=""
replace pilot="MEDAN" if substr(perid,1,1)=="9"
replace pilot="BANDUNG" if substr(perid,1,1)=="8"
qui count if pilot==""
assert `r(N)'==0

// TRUNCATES THE DATASET AT THE 12 MONTH MARK
// TWELVE MONTHS AFTER THE LAST ACTUAL DEADLINE
g after_oneyear=0

// MEDAN: MARCH 23rd 2016
replace after_oneyear=1 if year(signupdate)>2016&pilot=="MEDAN"
replace after_oneyear=1 if year(signupdate)==2016&month(signupdate)>3&pilot=="MEDAN"
replace after_oneyear=1 if year(signupdate)==2016&month(signupdate)==3&day(signupdate)>23&pilot=="MEDAN"

// BANDUNG: JANUARY 19th 2017
replace after_oneyear=1 if year(signupdate)>2017&pilot=="BANDUNG"
replace after_oneyear=1 if year(signupdate)==2017&month(signupdate)>1&pilot=="BANDUNG"
replace after_oneyear=1 if year(signupdate)==2017&month(signupdate)==1&day(signupdate)>19&pilot=="BANDUNG"

// TRUNCATES THE DATASET AT THE 24 MONTH MARK
// TWELVE MONTHS AFTER THE LAST ACTUAL DEADLINE

g after_twoyears=0

// MEDAN: MARCH 23rd 2017
replace after_twoyears=1 if year(signupdate)>2017&pilot=="MEDAN"
replace after_twoyears=1 if year(signupdate)==2017&month(signupdate)>3&pilot=="MEDAN"
replace after_twoyears=1 if year(signupdate)==2017&month(signupdate)==3&day(signupdate)>23&pilot=="MEDAN"

// BANDUNG: JANUARY 19th 2018
replace after_twoyears=1 if year(signupdate)>2018&pilot=="BANDUNG"
replace after_twoyears=1 if year(signupdate)==2018&month(signupdate)>1&pilot=="BANDUNG"
replace after_twoyears=1 if year(signupdate)==2018&month(signupdate)==1&day(signupdate)>19&pilot=="BANDUNG"

drop if after_twoyears==1

save data/working/enrollmentBPJS.dta, replace

***************************************
*** STEP 2: SM ENROLLMENT DATA      ***
***************************************

*********
* Medan *
*********

// EXCEL FILE REPORTING THOSE WHO ATTEMPTED BUT FAILED TO REGISTER
clear
insheet using A:/enrollmentSM/150316_BPJS_Gagal.txt, tab 

drop if no==.
ren namakepalakeluarga hhhname
ren voucer vc03
tostring vc03, replace format("%17.0f")
replace vc03 = "57431505901531" if vc03 == "57431505901511"
replace vc03 = "76521814903506" if vc03 == "76521654903506"
duplicates drop vc03, force

merge 1:m vc03 using data/raw/baseline_survey_medan_confidential/b1_vc.dta

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                         1,947
//         from master                         0  (_merge==1)
//         from using                      1,947  (_merge==2)
//
//     matched                                31  (_merge==3) enrolled at the office
//     -----------------------------------------

g intentenrollSM = 0
//attempted online enrollment in the first visit
replace intentenrollSM = 1 if vc03a == 1 	
//attempted online enrollment in the second visit
//note this is only for those who do not accept in first visit to avoid double counting
replace intentenrollSM = 1 if vc03a == 3 & vc03e ==1 & vc03a_1 == 1 
//attempted enrollment by going to BPJS office 
replace intentenrollSM = 1 if _merge ==3 

keep hhid intentenroll* vc03c vc03c_ot vc03c_1 vc03c_1_ot

tempfile intentenrollmedan
save `intentenrollmedan'

// EXCEL FILE W/ LIST OF HOUSEHOLD FOR WHICH WE ARE PAYING THE SUBSIDY
clear
insheet using A:/enrollmentSM/150907_BPJS_subsidi_medan.txt, tab
ren v1 hhid

drop if hhid == ""
replace hhid = substr(hhid,1,3)+substr(hhid,5,1)+substr(hhid,7,2)+substr(hhid,10,3)
replace hhid = "911B01192" if hhid == "911B 0 19"
replace hhid = "902E01006" if hhid == "902  0 00"

duplicates drop hhid, force

merge 1:1 hhid using data/raw/baseline_survey_medan_confidential/b1_vc.dta

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                         1,802
//         from master                         0  (_merge==1)
//         from using                      1,802  (_merge==2)
//
//     matched                               176  (_merge==3)
//     -----------------------------------------

*successful registration at BPJS office
g enrollatBPJSoffice = 0
replace enrollatBPJSoffice=1 if _merge==3

*successful registration onsite
g enrollonsite = 0
replace enrollonsite=1 if vc03b==1|vc03b_1==1

g actualenrollSM=0
replace actualenrollSM=1 if enrollatBPJSoffice==1|enrollonsite==1

keep hhid actualenrollSM

merge 1:1 hhid using `intentenrollmedan'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                             0
//     matched                             1,978  (_merge==3)
//     -----------------------------------------

drop _m

keep hhid intentenrollSM actualenrollSM

tempfile enrollmedanSM
save `enrollmedanSM'

***************
*** Bandung ***
***************

// EXCEL FILE WITH BOTH
clear
insheet using "A:/enrollmentSM/Registration form at BPJS Office_200116_fin.txt", tab

carryforward no, gen(no1)

*drops blank lines
drop if statusperlakuan==""&namaanggotakeluarga==""&nik==""

*drops additional individuals in hh
*drop if no==.

*gets voucher code
ren novoucher vc03
bysort no1: carryforward vc03, replace
tostring vc03, replace format("%17.0f")
tostring nik, replace format("%17.0f")

*drops duplicates
duplicates report vc03

*creates variables
ren keterangan notes
ren statussubsidiindividu persubsidy 
ren statussubsidikeluarga reportedsubsisdytmt

g success=0
replace success=1 if statuspendaftaran=="Berhasil"

*checks consisntency between notes and registration status
list notes if success==1&notes!=""
list notes if success==0&notes!=""

*keeps relevant variables
keep no vc03 reportedsubsisdytmt persubsidy success notes namaanggotakeluarga nik tanggalpendaftaran

g desa=substr(vc03,9,3)
destring desa, replace

drop if no==.

*corrects vc03 codes for matching
replace vc03="18533560812522" if vc03=="18533654812522"
replace vc03="54535654804591" if vc03=="54535171804591"
replace vc03="65536473802516" if vc03=="56636473802516"
replace vc03="37028678816504" if vc03=="37928678816504"
replace vc03="30230057801525" if vc03=="30230057801515"

*drops households with no voucher number
*these are the enumerators who took up our enrollment offer; drop them
tab notes if vc03=="."
drop if vc03=="."

merge 1:m vc03 using data/raw/baseline_survey_bandung_confidential/b1_vc.dta

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                         5,367
//         from master                         0  (_merge==1)
//         from using                      5,367  (_merge==2)
//
//     matched                               295  (_merge==3)
//     -----------------------------------------

***Intention to enroll***
***This is defined from data on enrollment from SurveyMeter***

g intentenrollSM = 0
//attempted online enrollment in the first visit
replace intentenrollSM = 1 if vc03a == 1 	
//attempted online enrollment in the second visit
//note this is only for those who do not accept in first visit to avoid double counting
replace intentenrollSM = 1 if vc03a == 3 & vc03e ==1 & vc03a_1 == 1 
//attempted enrollment by going to BPJS office, 
replace intentenrollSM = 1 if _merge ==3 

*successful registration at BPJS office
g enrollatBPJSoffice = 0
replace enrollatBPJSoffice =1 if _m==3&success==1

*successful registration onsite
g enrollonsite = 0
replace enrollonsite=1 if vc03b==1|vc03b_1==1

g actualenrollSM=0
replace actualenrollSM=1 if enrollatBPJSoffice==1|enrollonsite==1

keep hhid intentenrollSM actualenrollSM

append using `enrollmedanSM'

save data/working/enrollmentSM.dta, replace

