**--------------------------------------------------------------------------**
** This do file appends the Medan and Bandung datasets.						** 
** Last edited by Christy on Oct 9th										**
**--------------------------------------------------------------------------**
** 1. Data input         : data/codeddata/medaninddataset					**
** 						   data/codeddata/bandunginddataset					**
**--------------------------------------------------------------------------**
** 2. Output data        : data/codeddata/cleaned							**
**--------------------------------------------------------------------------**
	
use data/codeddata/inddatabase.dta, clear

drop vv*

foreach var of varlist infoextra bonussubsidy infomandate infowaiting halfsubsidy_onsite fullsubsidy_onsite halfsubsidy_infoextra fullsubsidy_infoextra bonussubsidy_onsite halfsubsidy_infowaiting fullsubsidy_infowaiting bonussubsidy_infowaiting halfsubsidy_infomandate fullsubsidy_infomandate bonussubsidy_infomandate  oneweektmt twoweekstmt choicetmt {
	replace `var'=0 if `var'==.
	}
g pilotbandung=(pilot=="BANDUNG")
replace oldr=1 if pilot=="MEDAN"

//////////////////////////////////////////////////////////////////////////////
// CREATES WEIGHTS TO CORRECT FOR RANDOMIZATION ISSUE FOR MEDAN AND BANDUNG //
//////////////////////////////////////////////////////////////////////////////

// 1. Medan weights

preserve

// keeps household sample
keep if rtsample==1

// keeps pilot
keep if pilot=="MEDAN"

// actual number
g actual_number_of_households = 1

// counts
collapse (sum) actual_number_of_households, by(nosubsidy halfsubsidy fullsubsidy infoextra onsite oneweektmt twoweekstmt choicetmt)

// total
egen total_hhs = total(actual_number_of_households)

// intended shares
g intended_share_subsidy = 1/3
g intended_share_infoextra = 0.50
g intended_share_onsite = 0.50
g intended_share_deadline = 1/3
replace intended_share_deadline = 1 if nosubsidy==1
g intended_share = intended_share_subsidy * intended_share_infoextra * intended_share_onsite * intended_share_deadline
g intended_number_of_households = intended_share * total_hhs

// weight
g weight_medan = intended_number_of_households / actual_number_of_households

keep weight_medan nosubsidy halfsubsidy fullsubsidy infoextra onsite oneweektmt twoweekstmt choicetmt

g pilot = "MEDAN"
g oldr = 1

tempfile medan_weights
save `medan_weights'

restore


// 2. Bandung old randomization weights

preserve

// keeps household sample
keep if rtsample==1

// keeps pilot
keep if pilot=="BANDUNG"
keep if oldr==1

// actual number
g actual_number_of_households = 1

// counts
collapse (sum) actual_number_of_households, by(nosubsidy halfsubsidy fullsubsidy bonussubsidy infomandate infowaiting onsite)

// total
egen total_hhs = total(actual_number_of_households)

// intended shares
g intended_share_subsidy = .
replace intended_share_subsidy = 0.50 if nosubsidy==1
replace intended_share_subsidy = 0.20 if halfsubsidy==1
replace intended_share_subsidy = 0.10 if fullsubsidy==1
replace intended_share_subsidy = 0.20 if bonussubsidy==1
g intended_share_infomandate = 0.50
g intended_share_infowaiting = 0.50
g intended_share_onsite = 0.50
g intended_share = intended_share_subsidy * intended_share_infomandate * intended_share_infowaiting * intended_share_onsite
g intended_number_of_households = intended_share * total_hhs

// weight
g weight_bandung = intended_number_of_households / actual_number_of_households

keep weight_bandung nosubsidy halfsubsidy fullsubsidy bonussubsidy infomandate infowaiting onsite

g pilot = "BANDUNG"
g oldr = 1

tempfile bandung_weights
save `bandung_weights'

restore

// 3. merges in weights
merge m:1 nosubsidy halfsubsidy fullsubsidy infoextra onsite oneweektmt twoweekstmt choicetmt pilot old using `medan_weights'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                        20,894
//         from master                    20,894  (_merge==1)
//         from using                          0  (_merge==2)
//
//     matched                             7,968  (_merge==3)
//     -----------------------------------------

drop _m

merge m:1 nosubsidy halfsubsidy fullsubsidy bonussubsidy infomandate infowaiting onsite pilot old using `bandung_weights'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                        22,064
//         from master                    22,064  (_merge==1)
//         from using                          0  (_merge==2)
//
//     matched                             6,798  (_merge==3)
//     -----------------------------------------

drop _m

// 4. creates weight variable
g weight=.
replace weight=weight_medan			if oldr==1&pilot=="MEDAN"
replace weight=weight_bandung		if oldr==1&pilot=="BANDUNG"
replace weight=1					if oldr==0&pilot=="BANDUNG"

drop weight_medan weight_bandung

count if weight==.
assert `r(N)'==0

// ADDITIONAL VARIABLES

// intentenroll_ST
cap drop intentenroll_ST
g intentenroll_ST=enroll_ST
replace intentenroll_ST=1 if intentenrollSM==1

// interactions
cap drop halfsubsidy_* fullsubsidy_* bonussubsidy_*

*nosubsidy_statusquoreg bonussubsidy_statusquoreg halfsubsidy_statusquoreg fullsubsidy_statusquoreg nosubsidy_onsitereg bonussubsidy_onsitereg halfsubsidy_onsitereg fullsubsidy_onsitereg

g nosubsidy_statusquoreg=nosubsidy*(onsite==0)
g nosubsidy_onsitereg=nosubsidy*(onsite==1)
g halfsubsidy_statusquoreg=halfsubsidy*(onsite==0)
g halfsubsidy_onsitereg=halfsubsidy*(onsite==1)
g fullsubsidy_statusquoreg=fullsubsidy*(onsite==0)
g fullsubsidy_onsitereg=fullsubsidy*(onsite==1)
g bonussubsidy_statusquoreg=bonussubsidy*(onsite==0)
g bonussubsidy_onsitereg=bonussubsidy*(onsite==1)

// dropoff
g dropoff=(intentenroll-enroll)

save data/codeddata/cleaned.dta , replace

