**************************************************************
*** Step 1 - Imports and cleans the BPJS payment data		***
***************************************************************

*************************************
*** MAY 2017 MATCH				  ***
*************************************

use "data/raw/bpjs_confidential/20170512 pembayaran.dta", clear

rename BULAN       bulan
rename TAHUN       tahun
rename TOTBYTAGIH  totbytagih 
rename TOTBYBAYAR  totbybayar

* selects the households not from Gresik
g desa=substr(hhid,1,3)
destring desa, replace
drop if inlist(desa,991,992,993)

*drops duplicates when we do not loose information
duplicates drop 

* creates the payment year + month variable
destring tahun, replace
destring bulan, replace
g yearmonth = ym(tahun,bulan) 
format %tm yearmonth

* checks for duplicates by perid and payment year + month
duplicates report perid membertag yearmonth
duplicates tag perid membertag yearmonth, g(dup)
sort perid membertag yearmonth

* corrects format of some of the variables for merge
destring totbytagih, replace
destring totbybayar, replace

* keeps the correct variables
keep totbytagih totbybayar perid yearmonth membertag

*ensures that the membertag refers to the correct nokapst
qui count
local N `r(N)'
ren membertag membertag_20170512
joinby perid membertag_20170512  using data/working/xwalk.dta, unmatched(both)
qui count if _m==3
assert `r(N)'==`N'
keep if _m==3
drop _m

// drops 2014
drop if year(dofm(yearmonth))==2014

ren totbytagih totbytagih_may
ren totbybayar totbybayar_may

tempfile payments_may17
save `payments_may17'


*************************************
*** AUG 2018 MATCH				  ***
*************************************

use "data/raw/bpjs_confidential/20180816 pembayaran.dta", clear

rename BULAN        bulan
rename TAHUN	    tahun
rename TAG_  		totbytagih 
rename BY_	  		totbybayar

* selects the households not from Gresik
g desa=substr(hhid,1,3)
destring desa, replace
drop if inlist(desa,991,992,993)

*drops duplicates when we do not loose information
duplicates drop 

* creates the payment year + month variable
destring tahun, replace
destring bulan, replace
g yearmonth = ym(tahun,bulan) 
format %tm yearmonth

* checks for duplicates by perid and payment year + month
duplicates report perid membertag yearmonth
duplicates tag perid membertag yearmonth, g(dup)
sort perid membertag yearmonth

* corrects format of some of the variables for merge
drop if totbytagih=="NULL"
drop if totbybayar=="NULL"
destring totbytagih, replace
destring totbybayar, replace

* keeps the correct variables
keep totbytagih totbybayar perid yearmonth membertag

*ensures that the membertag refers to the correct nokapst
qui count
local N `r(N)'
ren membertag membertag_20180816
joinby perid membertag_20180816  using data/working/xwalk.dta, unmatched(both)
qui count if _m==3
assert `r(N)'==`N'
keep if _m==3
drop _m

merge 1:1 perid membertag_final yearmonth using `payments_may17'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                        68,916
//         from master                    68,868  (_merge==1)
//         from using                         48  (_merge==2)
//
//     matched                            31,128  (_merge==3)
//     -----------------------------------------

//        perid |      Freq.     Percent        Cum.
// -------------+-----------------------------------
//  904A0106701 |         25       52.08       52.08
//  906A0100203 |         23       47.92      100.00
// -------------+-----------------------------------
//        Total |         48      100.00


drop _m

drop membertag_2* 
order perid membertag_final yearmonth totbytagih totbytagih_may totbybayar totbybayar_may

g class=.
replace class=1 if totbytagih==25500
replace class=2 if totbytagih==42500|totbytagih==51000
replace class=3 if totbytagih==59500|totbytagih==80000

bysort perid membertag_final: egen classmax=max(class)
bysort perid membertag_final: egen classmin=min(class)

// missing are the two observations that do not merge 
// and two observations that get charged 33402
// consider them as class 1
tab classmin classmax, m

replace class=1 if classmin==1&classmax==1
replace class=2 if classmin==2&classmax==2
replace class=3 if classmin==3&classmax==3
replace class=1 if classmin==.&classmax==.

sort perid membertag_final yearmonth 

bysort perid membertag_final (yearmonth): g obs=_n
bysort perid membertag_final (yearmonth): g obs_reverse=_N-obs

g sample=""
replace sample="class1" if class==1
replace sample="class2" if class==2
replace sample="class3" if class==3

drop if yearmonth==.

sort perid membertag_final yearmonth 

g totbytagih_orig=totbytagih
g totbybayar_orig=totbybayar

// var to keep track of premium
g premium_due=.
replace premium_due=25500 if class==1
replace premium_due=42500 if class==2&yearmonth<=675
replace premium_due=51000 if class==2&yearmonth>675
replace premium_due=59500 if class==3&yearmonth<=675
replace premium_due=80000 if class==3&yearmonth>675

bysort perid membertag_final: g totobs=_N
tab obs if totbytagih==0
tab obs if totbytagih==0&obs!=totobs
replace totbytagih=. if totbytagih==0&obs==totobs

// IGNORES CASES IN WHICH HAVE A 0 THE MONTH BEFORE YOU EXIT THE DATABASE
bysort perid membertag_final: egen tochange=max(totbytagih==0)

// these are adjustments when premium changes
replace totbybayar=0 if totbybayar==8500

// TOTBYTAGIH==0 & OBS==2 + TOTBYBYAR ==0 & OBS==1
// PAID FOR THE FIRST MONTH BUT THE PREMIUM COVERS THE SECOND
bysort perid membertag_final (obs): g tag=(totbytagih==0&obs==2&totbybayar[_n-1]==0)
bysort perid membertag_final: egen tagged=max(tag)
bysort perid membertag_final (obs): replace totbytagih=premium_due if tag==1
bysort perid membertag_final (obs): replace totbytagih=. if tag[_n+1]==1

// IN ALL OTHER CASES, WHEN TOTBYTAGIH==0 USE THAT MONTH TO COVER THE NEXT MONTH WITH TOTBYBAYAR==0
cap drop tag*
g tag=(totbytagih==0)
bysort perid membertag_final: egen tagged=max(tag)
bysort perid membertag_final (obs): egen tag_obs=min(obs/(totbytagih==0))
bysort perid membertag_final (obs): egen tag_zero=min(obs/(totbybayar==0&obs>=tag_obs))
bysort perid membertag_final (obs): egen changed=max(tagged==1&obs==tag_zero)
bysort perid membertag_final (obs): replace totbybayar=totbybayar[tag_obs] if tagged==1&obs==tag_zero
bysort perid membertag_final (obs): replace totbybayar=0 if tagged==1&obs==tag_obs
replace totbytagih=premium_due if tagged==1&tag==1&changed==1
replace totbytagih=. if tagged==1&tag[_n+1]==1&changed==1

drop if totbytagih==.

// THIS CREATES THE MONTHLY LEVEL PAYMENT DATA FROM THE LATEST EXTRACT
// NOTE: WE ASSUME LARGE PAYMENTS ARE FIRST USED TO COVER BACKMONTHS
// AND THEN TO PAY IN ADVANCE FOR FUTURE MONTHS
// THIS MATCHES THE MAY EXTRACT DATA FOR WHICH WE HAVE DETAILED INFORMATION ON
// MONTHS IN WHICH PREMIUM IS COVERED

g totbybayar_ORIG_NEW = totbybayar

pause off 
// CLASS 1
foreach sample in class1 class2 class3 {
	
	if "`sample'"=="class1"			local premium 	25500
	if "`sample'"=="class2"			local premium 	42500
	if "`sample'"=="class3"			local premium 	59500
	
	if "`sample'"=="class1"			local premium_alt 	25500
	if "`sample'"=="class2"			local premium_alt 	51000
	if "`sample'"=="class3"			local premium_alt 	80000

	preserve

	keep if sample=="`sample'"
	
	levelsof totbybayar if totbybayar>0, local(amounts)
	g nmonths_old=(yearmonth-675)

	foreach amount in `amounts' {
		if `amount'==`premium'|`amount'==`premium_alt' {
			}
		else {
			di "`amount'"
			local count =1 
			while `count' > 0 {
				cap drop tochange*

				bysort perid membertag_final: egen tochange_ym=min(obs/(totbybayar==`amount'))			
				local n_months = int(`amount'/`premium')
				di `n_months'
				
				bysort perid membertag_final: egen tochange_num=total((totbybayar==0&obs>=tochange_ym-`n_months'+1&obs<tochange_ym))
				g tochange_before=(tochange_num==`n_months'-1&tochange_num>0)
				
				g tochange=((totbybayar==0&obs>=tochange_ym-`n_months'+1&obs<tochange_ym))
				
				cap drop tempvar*
				g tempvar1=(-1)*totbytagih if tochange_before==1&tochange==1
				replace tempvar1=totbybayar if tochange_before==1&obs==tochange_ym
				
				bysort perid membertag_final (obs_reverse): g tempvar2=sum(tempvar1)
				replace tempvar2=. if tempvar2<totbytagih
				replace tempvar2=. if tempvar1==.
				replace tempvar2=totbytagih if tempvar2>0&tempvar2!=.
								
				replace totbybayar=tempvar2 if tempvar2!=.			
				
				count if totbybayar==`amount'&tochange_before==1
				local count = `r(N)'
				
				}
			}
		}
			
	g keep_track_before = (totbybayar!=totbybayar_orig)
	
	foreach amount in `amounts' {
		if `amount'==`premium'|`amount'==`premium_alt' {
			}
		else {
			di "`amount'"
			local count =1 
			while `count' > 0 {
				cap drop tochange_after 
				cap drop tochange
				cap drop tochange_ym
				cap drop tochange_num

				bysort perid membertag_final: egen tochange_ym=min(obs/(totbybayar==`amount'))
				local n_months = int(`amount'/`premium')
				di `n_months'
				
				bysort perid membertag_final: egen tochange_num=total((totbybayar==0&obs>tochange_ym&obs<=tochange_ym+`n_months'-1))
				g tochange_after=(tochange_num<=`n_months'-1&tochange_num>0)
				
				g tochange=(totbybayar==0&obs>tochange_ym&obs<=tochange_ym+`n_months'-1)
				
				cap drop tempvar*
				g tempvar1=(-1)*totbytagih if tochange_after==1&tochange==1
				replace tempvar1=totbybayar if tochange_after==1&obs==tochange_ym
				
				bysort perid membertag_final (obs): g tempvar2=sum(tempvar1)
				replace tempvar2=. if tempvar2<totbytagih
				replace tempvar2=. if tempvar1==.
				replace tempvar2=totbytagih if tempvar2>0&tempvar2!=.
				
				replace totbybayar=tempvar2 if tempvar2!=.			

				count if totbybayar==`amount'&tochange_after==1
				local count = `r(N)'

				}
			}
		}

	g keep_track_after = (totbybayar!=totbybayar_orig)
	
	tempfile `sample'
	save ``sample'', replace
	
	restore
	}

// appends the datasets

use `class1', clear
append using `class2'
append using `class3' 

// checks that newly created variables corresponds to the May ones
g paid_may=(totbybayar_may!=.&totbybayar_may!=0)
g paid=(totbybayar!=.&totbybayar!=0)

tab paid paid_may
tab paid paid_may if year(dofm(yearmonth))<2017|year(dofm(yearmonth))==2017&month(dofm(yearmonth))<=4

bysort perid membertag_final: egen tocheck=max(paid!=paid_may&year(dofm(yearmonth))<2017|paid!=paid_may&year(dofm(yearmonth))==2017&month(dofm(yearmonth))<=4)

sort perid membertag_final yearmonth 
			
keep perid membertag_final yearmonth totbytagih totbybayar 

save data/working/payments.dta, replace

***************************************************************
*** Step 2 - Gets payments by month since offer/enrollment	***
***************************************************************

use data/working/payments.dta, clear

* merges with information from the baseline
preserve
use data/working/baseline_with_enrollment.dta, clear
keep perid membertag_final BPJSadmin_m signupdate firstsignuprt enroll* dobok restrictedsample membership offerdate nosubsidy halfsubsidy fullsubsidy bonussubsidy onsite pilot
tempfile signupdates
save `signupdates'
restore

merge m:1 perid membertag_final using `signupdates'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                        25,467
//         from master                       784  (_merge==1)
//         from using                     24,683  (_merge==2)
//
//     matched                            98,725  (_merge==3)
//     -----------------------------------------

// _m==1: observations that have been dropped from BPJSenrollment.dta
//        corrected duplicates, observations enrolled after one year from offerdate
//        checked at the end of paymentcleaning.do
keep if _m==3
drop _m

g yearmonthsignup = ym(year(firstsignuprt),month(firstsignuprt)) 
format %tm yearmonthsignup
g yearmonthofferdate = ym(year(offerdate),month(offerdate)) 
format %tm yearmonthofferdate

g em_offer=yearmonth-yearmonthofferdate+1
g em_signup=yearmonth-yearmonthsignup+1

g earlypayment_signup=0
replace earlypayment_signup=1 if year(dofm(yearmonth))<year(firstsignuprt)
replace earlypayment_signup=1 if year(dofm(yearmonth))==year(firstsignuprt)&month(dofm(yearmonth))<month(firstsignuprt)

g earlypayment_offer=0
replace earlypayment_offer=1 if year(dofm(yearmonth))<year(offerdate)
replace earlypayment_offer=1 if year(dofm(yearmonth))==year(offerdate)&month(dofm(yearmonth))<month(offerdate)

* keeps only individuals who are considered enrolled
* these people either never enroll (have no signup date and there em_signup missing)
* or enroll after 12 months since offerdate
* we are not interested in them so we can drop them
tab em_signup enroll, m
tab em_offer enroll if em_signup!=.
drop if enroll_2yrs==0
mdesc em_signup
mdesc em_offer

// CORRECTS THE ENROLLMENT MONTHS SINCE SIGNUPDATE
// 221 OBSERVATIONS DO NOT HAVE PAYMENT IN FIRST MONTH
// IN 103 CASES, THESE INDIVIDUALS HAVE A PAYMENT REGISTERED IN THE PREVIOUS MONTH
// THEY ARE ALMOST ALL INDIVIUALS WHO ENROLLED IN THE FIRST WEEK OF THE MONTH, AND IT TAKES ABOUT A WEEK FOR BPJS TO ACTIVATE MEMBERSHIP
// THEY ACTUALLY ENROLLED AND PAID AT THE END OF THE PREVIOUS MONTH
// IT IS JUST SHIFTED --> CORRECT
bysort perid : egen hasenrollmonth0=max((em_signup==0))
bysort perid : egen hasenrollmonth1=max((em_signup==1))
bysort perid : egen hasenrollmonth2=max((em_signup==2))
bysort perid : g n=_n
tab hasenrollmonth1 if n==1
tab hasenrollmonth0 hasenrollmonth1 if n==1
tab signupdate if hasenrollmonth0==1&hasenrollmonth1==0&n==1
replace yearmonth=yearmonth+1 if em_signup==0&hasenrollmonth1==0&hasenrollmonth0==1
replace em_signup=em_signup+1 if em_signup==0&hasenrollmonth1==0&hasenrollmonth0==1

// IF PEOPLE SIGNUP AT THE END OF THE MONTH, PREMIUM MAY COVER FOLLOWING MONTH
// NO MONTH1 BUT HAS MONTH2 (AND MONTHS AFTER THAT)
// THESE LOOK LIKE PEOPLE WHO SIGN UP AT THE END OF THE MONTH AND WHOSE PAYMENT GOES TOWARDS THE FOLLOWING MONTH
// IN BANDUNG YOU WOULD SIGNUP AT THE OFFICE THEN WAIT TWO WEEKS BEFORE SUBMITTING THE FIRST PAYMENT
// SO THIS PATTERN MAKES SENSE; AND ALSO EXPLAINS WHY WE SEE SO MANY MORE CASES IN BANDUNG V. MEDAN
cap drop hasenrollmonth*
bysort perid : egen hasenrollmonth1=max((em_signup==1))
bysort perid : egen hasenrollmonth2=max((em_signup==2))
bysort perid : egen hasenrollmonth3=max((em_signup==3))
replace em_signup=em_signup-1 if hasenrollmonth1==0&hasenrollmonth2==1

// NO MONTH2 BUT HAS MONTH1 AND MONTH3
// CORRECT MONTH 3 TO BE MONTH 2 AND SO ON
g month2corrected=(hasenrollmonth1==1&hasenrollmonth2==0&hasenrollmonth3==1)
replace yearmonth=yearmonth+1 if em_signup==1&hasenrollmonth1==1&hasenrollmonth2==0&hasenrollmonth3==1&day(firstsignuprt)>25&firstsignuprt!=.
replace em_signup=em_signup-1 if em_signup!=1&hasenrollmonth1==1&hasenrollmonth2==0&hasenrollmonth3==1&day(firstsignuprt)>25&firstsignuprt!=.

cap drop hasenrollmonth*
bysort perid : egen hasenrollmonth1=max((em_signup==1))
tab hasenrollmonth1 if n==1

// NO CORRECTION FOR THE EM_OFFER VARIABLE NECESSARY

// DROPS PAYMENTS BEFORE THE SIGNUPDATE
drop if em_signup<=0

// SAVES FILE FOR LATER (NEEDED TO CLEAN CLAIMS DATA)
preserve
keep perid membertag_final yearmonth em_signup em_offer month2corrected
bysort perid membertag_final: egen lastmonthpaid=max(yearmonth)
format %tm lastmonthpaid
save data/working/enrollment_month.dta, replace
restore 

* drops unnecessary variables
drop signupdate firstsignuprt  

tempfile payment_temporary
save `payment_temporary', replace

*****************************
** Months since offer date **
*****************************

use `payment_temporary', clear

keep if em_offer>=1&em_offer<=25

* creates balanced panel to keep track of missings months
egen id=group(perid membertag_final)
g enrollmonthpaid=em_offer
tsset id em_offer
tsfill, full

sort id perid membertag_final
bysort id: replace perid=perid[_N] if perid==""
bysort id: replace membertag_final=membertag_final[_N] if membertag_final==.

* creates the paystatus variable
cap drop paystatus_offer
g paystatus_offer = (totbybayar>0&totbybayar!=.)
label define paylabel 0 "Not paid" 1 "Paid"
label value paystatus_offer paylabel
count if paystatus_offer==.
assert `r(N)'==0

* gets payment amounts
// count if totbytagih!=totbybayar XX why? XX
// assert `r(N)'==0
ren totbybayar payamount_offer

* keeps the relevant variables
keep perid payamount_offer paystatus_offer em_offer membertag_final

reshape wide payamount paystatus, i(perid membertag_final) j(em_offer)

tempfile em_offer
save `em_offer'

**********************************
** Months since enrollment date **
**********************************

use `payment_temporary', clear

keep if em_signup>=1&em_signup<=24

* creates balanced panel to keep track of missings months
egen id=group(perid membertag_final)
g enrollmonthpaid=em_signup
tsset id em_signup
tsfill, full

sort id perid membertag_final
bysort id: replace perid=perid[_N] if perid==""
bysort id: replace membertag_final=membertag_final[_N] if membertag_final==.

* creates the paystatus variable
cap drop paystatus_signup
g paystatus_signup = (totbybayar>0&totbybayar!=.)
label value paystatus_signup paylabel
count if paystatus_signup==.
assert `r(N)'==0

* gets payment amounts
// count if totbytagih!= totbybayar
// assert `r(N)'==0
ren totbybayar payamount_signup

* keeps the relevant variables
keep perid paystatus_signup payamount_signup em_signup membertag_final 

reshape wide paystatus payamount, i(perid membertag_final) j(em_signup)

merge 1:1 perid membertag_final using `em_offer'

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                             2
//         from master                         2  (_merge==1) 
//         from using                          0  (_merge==2)
//
//     matched                             2,379  (_merge==3)
//     -----------------------------------------

// _m==1: PEOPLE WHO HAVE NO PAYMENTS IN FIRST 15 MONTHS SINCE OFFERDATE BUT HAVE PAYMENTS IN FIRST 16 MONTHS SINCE SIGNUP
//        SIGNUP STRETCHES FURTER IN TIME IF LATER THAN OFFER

drop _m

save data/working/payment_cleaned.dta, replace

*****************************************************************
*** Step 3 - Gets the SM payment data                         ***
*****************************************************************

*************
*** Medan *** 
*************

// IMPORTS LIST OF INDIVIDUALS FOR WHICH SM IS PAYING SUBSIDY
// LIST FROM SM HAS HHID, NAME AND BPJSID -- NEED TO LINK PERID
// USE HHID + NAME (MANUALPERIDMATCH)

* imports hhid, name, perid from the baseline
use A:/baseline_survey_medan/b1_ar.dta, clear

* creates variables
ren ar01 nama
tostring ar00, g(urut)
replace  urut="0"+urut if length(urut)==1
gen	 perid=hhid+urut
g idu=_n

keep hhid perid nama idu

tempfile pii
save `pii'

* imports SM log
clear
insheet using A:/enrollmentSM/150907_BPJS_subsidi_medan_full.txt, tab 

* creates the name variable
g nama=subinstr(upper(keterangantransaksi),"PEMBAYARAN BPJS ATAS NAMA ","",.)
replace nama=subinstr(upper(nama),"PEMBAYARAN BPJS ","",.)
replace nama=subinstr(upper(nama),"PEMBAYARN BPJS ","",.)
replace nama=regexs(1) if regexm(nama,"([A-Z ]+)([(])")==1
replace nama=strtrim(nama)

* creates hhid
g hhid=subinstr(hhid_sesudah_clean," ","",.)
replace hhid="ENUMERATORS" if perlakuan=="VOUCHER UTK KK ASISTEN PENELITI" // enumerators
sort no
replace hhid=hhid[_n-1] if hhid==""
replace hhid="904A01023" if hhid=="ENUMERATORS"&nama=="MHD TAHIR" 

tostring id_peserta_bpjs, generate(id_peserta_bpjs2) format(%11.0f)
gen nokapst = substr(id_peserta_bpjs2,1,9)

g idm=_n

count
reclink hhid nama using `pii', idu(idu) idm(idm) require(hhid) gen(s)

* drops enumerators
drop if hhid=="ENUMERATORS"

* makes changes usind nokapst from nokapstlink
replace perid="901A0101201" if perid==""&nokapst=="182283570"
replace perid="911B0139201" if perid==""&nokapst=="182978030"
replace perid="907J0102704" if perid==""&nokapst=="182780841"
replace perid="907D0101802" if perid==""&nokapst=="182537581"
replace perid="906A0100203" if perid=="906A0100205"&nokapst=="182491306"

tab _m

* keeps perid only
keep perid
drop if perid==""

g jpalpaymentok=1

* saves file
tempfile medan_SMpaymentlog
save `medan_SMpaymentlog', replace


***************
*** Bandung *** 
***************

// IMPORTS LIST OF INDIVIDUALS FOR WHICH SM IS PAYING SUBSIDY
// LIST FROM SM HAS HHID, NAME AND BPJSID -- NEED TO LINK PERID
// USE HHID + NAME (MANUALPERIDMATCH)

* imports hhid, name, perid from the baseline
use A:/baseline_survey_bandung/B1_AR1.dta, clear

g hhid=b1_ea+b1_ds+b1_sls2+b1_k

* creates variables
ren ar01 nama
tostring ar00, g(urut)
replace  urut="0"+urut if length(urut)==1
gen	 perid=hhid+urut
g idu=_n

keep hhid perid nama idu

tempfile pii
save `pii'

* imports SM log
clear
insheet using "A:/enrollmentSM/Registration form at BPJS Office_200116_fin.txt", tab

* drops observations that have all missing values 
* if the name variable is missing then that observation has missing values for all variables
drop if namaanggotakeluarga==""
ren namaanggotakeluarga nama

* creates hhid
replace hhid="ENUMERATORS" if keterangan=="SUBSIDI UNTUK ASISTEN PENELITI" // enumerators
replace hhid=hhid[_n-1] if hhid[_n]==""

g idm=_n

count
reclink hhid nama using `pii', idu(idu) idm(idm) require(hhid) gen(s)

drop if hhid=="ENUMERATORS"
replace perid="806A01000303" if hhid=="806A010003"&nama=="DEDE ROPIK AHMAD CBK"

* drops self-sponsored
drop if statussubsidiindividu=="Ditanggung Sendiri"

* keeps track of failed payment
g jpalpaymentok=1
replace jpalpaymentok=0 if statuspendaftaran=="Gagal"
replace jpalpaymentok=0 if statuspembayaran=="GAGAL"
replace jpalpaymentok=0 if vanumber==.

mdesc perid

* keeps perid only
keep perid jpalpaymentok
drop if perid==""

* appends Medan
append using `medan_SMpaymentlog'

* saves file
save data/working/paymentsSM.dta, replace


