***********************************************************
*** Merges all files and creates relevant variables		***
***********************************************************

use data/working/baseline_with_payment.dta, clear

merge 1:1 perid membertag_final using data/working/claims_cleaned.dta  

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                        27,600
//         from master                    27,579  (_merge==1)
//         from using                         21  (_merge==2)
//
//     matched                             1,178  (_merge==3)
//     -----------------------------------------

// _m==2 claims from duplicates that were dropped

// bysort perid: egen temp=max(dup_perid_raw)
// count if _m==2&dup_perid_raw!=0&dup_perid_raw!=.
// assert `r(N)'==0
drop if _m==2
drop _m
// drop temp

* creates the rt level variables
* does not include individuals with the wrong date of birth (they are not consider them to be right match)
foreach var of varlist outind* outhospind* outind* inpind* chronicind* anyind* anyhospind*  {
	qui replace `var'=0 if `var'==.
	qui replace `var'=0 if dobok==0
	}
foreach var of varlist firstclaimind* {
	qui replace `var'=. if dobok==0
	}

* creates the days to first claim variable
* the refereence date is the first signup date that is ok
replace firstclaimind=. if dobok==0
bysort hhid: egen firstclaimrt=min(firstclaimind) 
g temp=firstclaimrt-firstsignuprt if enroll==1
bysort hhid: egen daystofirstclaimrt=min(temp)
format %td firstclaimrt 
drop temp

foreach time in signup1 offer_1to12 offer_13to20 signup_1to12 signup_13to20 {

	*creates the temp variables
	bysort hhid: egen outrt_`time'=max(outind_`time')
	bysort hhid: egen outhosprt_`time'=max(outhospind_`time')
	bysort hhid: egen inprt_`time'=max(inpind_`time')
	bysort hhid: egen anyrt_`time'=max(anyind_`time')
	bysort hhid: egen chronicrt_`time'=max(chronicind_`time')
	bysort hhid: egen anyhosprt_`time'=max(anyhospind_`time')
	bysort hhid: egen outrtnum_`time'=total(outindnum_`time')
	bysort hhid: egen outhosprtnum_`time'=total(outhospindnum_`time')
	bysort hhid: egen inprtnum_`time'=total(inpindnum_`time')
	bysort hhid: egen anyrtnum_`time'=total(anyindnum_`time')
	bysort hhid: egen anyhosprtnum_`time'=total(anyhospindnum_`time')
	bysort hhid: egen chronicrtnum_`time'=total(chronicind_`time')
	bysort hhid: egen outhosprttotvalue_`time'=total(outhospindtotvalue_`time')
	bysort hhid: egen inprttotvalue_`time'=total(inpindtotvalue_`time')
	bysort hhid: egen anyrttotvalue_`time'=total(anyindtotvalue_`time')
	g inpatandoutpat_`time'=(outrt_`time'==1&inprt_`time'==1)

	if "`time'"=="offer_1to12" {
		bysort hhid: egen firstclaimrt_`time'=min(firstclaimind_`time')
		g daystofirstclaimrt_`time'=firstclaimrt_`time'-offerdate
		format %td firstclaimrt_`time'
		}
	if "`time'"=="signup_1to12"|"`time'"=="signup_1to3" {
		bysort hhid: egen firstclaimrt_`time'=min(firstclaimind_`time')
		g daystofirstclaimrt_`time'=firstclaimrt_`time'-firstsignuprt
		format %td firstclaimrt_`time'
		}
	
	}	

save data/working/baseline_with_claims.dta, replace

