********************************************************
*** Merges the baseline data and the enrollment data ***
********************************************************

// Baseline
use data/working/medanbaseline_with_pii.dta, clear 

append using data/working/bandungbaseline_with_pii.dta

// renames date of birth
ren dateofbirth dob_baseline

// Enrollment from SM data
merge m:1 hhid using data/working/enrollmentSM.dta  

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                             0
//     matched                            28,664  (_merge==3)
//     -----------------------------------------

qui count if _m!=3
assert `r(N)'==0
drop _m

// Enrollment from BPJS administrative data
// 1:m merge because BPJS data contains duplicates
merge 1:m perid using data/working/enrollmentBPJS.dta

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                        22,527
//         from master                    22,527  (_merge==1)
//         from using                          0  (_merge==2)
//
//     matched                             6,230  (_merge==3)
//     -----------------------------------------

ren _m BPJSadmin_m
replace membertag_final=1 if BPJSadmin_m==1

// RE-CREATES THE RTSAMPLE VARIABLE TO KEEP TRACK OF THE FACT THAT IF DUPLICATES IS THE HHHEAD WE MAY END UP WITH TWO OBSERVATIONS WITH RTSAMPLE=1 IN ONE HH
drop rtsample
sort hhid perid
bysort hhid: g n=_n
g rtsample=0
replace rtsample=1 if n==1
drop n

// ENROLLMENT VARIABLES
// INDIVIDUAL IS MATCHED IF THEY HAVE A MATCH WITH YEAR OF BIRTH WITHIN 1 YEAR FROM YEAR OF BIRTH REPORTED IN THE BASELINE
g BPJSmatch=(BPJSadmin_m==3&dobok==1)
bysort hhid: egen BPJSmatchrt=max(BPJSmatch) //at least one member of the household has a match

// MEMBERSHIP and SIGNUPDATE

* generates variable on signupdate
format %td signupdate 
tab signupdate
gen signupok=(BPJSmatch==1&signupdate>=offerdate&signupdate!=.)
bysort pilot: tab signupdate if signupok==1

* cleans membership 
bysort pilot: tab membership if BPJSmatch==1, m
replace membership="PEKERJA BUKAN PENERIMA UPAH" if membership=="BUKAN PEKERJA"|membership=="PBPU"|membership=="BP"

* creates the signupdate of reference for the claims variables
* the refereence date is the first signup date that is ok
g signupdateok=signupdate if signupok==1
g tempsignupdate=signupdateok if membership=="PEKERJA BUKAN PENERIMA UPAH"
bysort hhid: egen firstsignuprt=min(tempsignupdate)
drop tempsignupdate
format %td firstsignuprt 

* generates variable to keep track of enrollment within ONE YEAR FROM OFFERDATE
g withinayear=(firstsignuprt<=offerdate+365&firstsignuprt!=.)

* generates variables on membershiptype & signupdate
cap drop temp*
cap drop membershipsignupdateok
g membershipsignupdateok=(membership=="PEKERJA BUKAN PENERIMA UPAH"&signupok==1)
bysort hhid: egen temp1=min(membershipsignupdateok)
bysort hhid: egen temp2=max(membershipsignupdateok)
tab temp1 temp2
tab temp1 temp2 if BPJSmatchrt==1
g membersignupdateokrt_all=(temp1==1&temp2==1)
g membersignupdateokrt_some=(temp1==0&temp2==1)
g membersignupdateokrt_none=(temp1==0&temp2==0&BPJSmatchrt==1)

* generates enrollment variables
* enroll: hh w/ at least one match in the BPJS data and st at least one match has ok signupdate and ok membershiptype
#delimit ;
g enroll=	(
			BPJSmatchrt==1&membersignupdateokrt_all==1&withinayear==1 |
			BPJSmatchrt==1&membersignupdateokrt_some==1&withinayear==1		
			);
#delimit cr

*creates deadline variable (use 30 days -- 15 days voucher deadline and 15 days to start administrative -- + 10 to allow for some additional time)
g deadline=offerdate+8*7
format %td deadline

cap drop temp*
cap drop signupokST
g signupokST=signupok
replace signupokST=0 if signupdate>deadline

* generates variables on membershiptype & signupdate
cap drop temp*
cap drop membershipsignupdateokST*
g membershipsignupdateokST=(membership=="PEKERJA BUKAN PENERIMA UPAH"& signupokST==1)
bysort hhid: egen temp1=min(membershipsignupdateokST)
bysort hhid: egen temp2=max(membershipsignupdateokST)
tab temp1 temp2
cap drop membersignupdateokrtST*
g membersignupdateokrtST_all=(temp1==1&temp2==1)
g membersignupdateokrtST_some=(temp1==0&temp2==1)
g membersignupdateokrtST_none=(temp1==0&temp2==0&BPJSmatchrt==1)

* generates enrollment variables
* enroll: hh w/ at least one match in the BPJS data and st at least one match has ok signupdate and ok membershiptype
cap drop enroll_ST
#delimit ;
g enroll_ST=	(
			BPJSmatchrt==1&membersignupdateokrtST_all==1 |
			BPJSmatchrt==1&membersignupdateokrtST_some==1 		
			);
#delimit cr

* enroll long term
g enroll_LT=(enroll==1&enroll_ST==0)

* enroll_all: hh w/ at least one match in the BPJS data 
g enroll_all=(BPJSmatchrt==1)

* generates sample restriction
* we want to exclude households who already had HI when we visited them
* we exclude households with all matched members having enrollment date prior to offerdate
cap drop temp*
cap drop hadHI*
g hadHI_ind=1 if after_oneyear==0&BPJSmatch==1&signupdate<offerdate&signupdate!=.
replace hadHI_ind=2 if after_oneyear==0&BPJSmatch==1&signupdate>=offerdate&signupdate!=.
bysort hhid: egen temp1=min(hadHI_ind)
bysort hhid: egen temp2=max(hadHI_ind)
g hadHI=(temp1==temp2&temp1==1)

g restrictedsample=1-hadHI

* defines intent to enroll variables
g intentenroll=enroll
replace intentenroll=1 if intentenrollSM==1
g intentenroll_all=enroll_all
replace intentenroll_all=1 if intentenrollSM==1
g intentenroll_ST=enroll_ST
replace intentenroll_ST=1 if intentenrollSM==1

ren intentenrollSM intentenroll_restrictedSM
g intentenrollSM=intentenroll_restrictedSM
replace intentenrollSM=1 if actualenrollSM==1

drop temp*

// WITHIN TWO YEARS
* generates variable to keep track of enrollment within ONE YEAR FROM OFFERDATE
g withintwoyears=(firstsignuprt<=offerdate+2*365&firstsignuprt!=.)
#delimit ;
g enroll_2yrs=	(
			BPJSmatchrt==1&membersignupdateokrt_all==1&withintwoyears==1 |
			BPJSmatchrt==1&membersignupdateokrt_some==1&withintwoyears==1		
			);
#delimit cr

save data/working/baseline_with_enrollment.dta, replace
