***********************************************************
*** Merges all files and creates relevant variables		***
***********************************************************

use data/working/baseline_with_enrollment.dta, clear

merge 1:1 perid membertag_final using data/working/payment_cleaned.dta

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                        26,412
//         from master                    26,412  (_merge==1)
//         from using                          0  (_merge==2)
//
//     matched                             2,381  (_merge==3)
//     -----------------------------------------

qui count if _m==2
assert `r(N)'==0
g inpaymentdata=(_m==3)
drop _m

* merges information on whether SM is paying subsidy for enrollmonth <=12
merge m:1 perid using data/working/paymentsSM.dta

//     Result                           # of obs.
//     -----------------------------------------
//     not matched                        27,563
//         from master                    27,563  (_merge==1)
//         from using                          0  (_merge==2)
//
//     matched                             1,230  (_merge==3)
//     -----------------------------------------

count if _m==2
assert `r(N)'==0

* creates the paidbySM variable
gen inSMpaymentdata=(_m==3)
gen paidbyjpal=(_m==3&jpalpaymentok==1)
la var paidbyjpal "Subsidy paid by J-PAL"
drop _m

*********************************************************
* Defines the variables for the analysis 				*
*********************************************************

// paid1-paid16 dummies (individual level)
forvalues month=1(1)24 {
	g paid_offer`month'=(paystatus_offer`month'==1|paystatus_offer`month'==2)
	}
	
// PAYMENT STATUS AND AMOUNT FOR SELF SPONSORED INDIVIDUALS
// defines sample for the payment analysis w/in the first year since offerdate
// self-sponsored individuals that should be paid for
// only relevant for months 1 to 13
// hh is defined as "paid" if they pay for all the members they should be paying for

g samplepayment_ssp=0
replace samplepayment_ssp=1 if enroll_2yrs==1
replace samplepayment_ssp=0 if enroll_2yrs==1&fullsubsidy==1&paidbyjpal==1
replace samplepayment_ssp=0 if enroll_2yrs==1&halfsubsidy==1&paidbyjpal==1
replace samplepayment_ssp=0 if enroll_2yrs==1&BPJSmatch==0
replace samplepayment_ssp=0 if enroll_2yrs==1&membership!="PEKERJA BUKAN PENERIMA UPAH"

cap drop hhsize
bysort hhid: egen hhsize_payment=total(samplepayment_ssp)

// paid status by offer date
// amount paid by offer date
forvalues month=1(1)24 {
	* payment status
	cap drop temp_paid`month'
	g temp_paid`month'=(paid_offer`month'==1&samplepayment_ssp==1)
	bysort hhid: egen temp_numberpaid_offer`month'=total(temp_paid`month')
	g paidrt_ssp_offer`month'=(temp_numberpaid_offer`month'==hhsize_payment&hhsize_payment!=0)
	
	* payment amount
	cap drop temp_amount`month'
	g temp_amount`month'=payamount_offer`month' if samplepayment_ssp==1
	bysort hhid: egen paidrt_ssp_amount_offer`month'=total(temp_amount`month')
	}
cap drop temp_*
	
// summary variables
egen paidrt_ssp_num=rsum(paidrt_ssp_offer1 paidrt_ssp_offer2 paidrt_ssp_offer3 paidrt_ssp_offer4 paidrt_ssp_offer5 paidrt_ssp_offer6 paidrt_ssp_offer7 paidrt_ssp_offer8 paidrt_ssp_offer9 paidrt_ssp_offer10 paidrt_ssp_offer11 paidrt_ssp_offer12)
foreach interval in 1 3 6 12 {
	g paidrt_ssp_`interval'm=(paidrt_ssp_num>=`interval'&paidrt_ssp_num!=.)
	}
egen paidrt_ssp_amount=rsum(paidrt_ssp_amount_offer1 paidrt_ssp_amount_offer2 paidrt_ssp_amount_offer3 paidrt_ssp_amount_offer4 paidrt_ssp_amount_offer5 paidrt_ssp_amount_offer6 paidrt_ssp_amount_offer7 paidrt_ssp_amount_offer8 paidrt_ssp_amount_offer9 paidrt_ssp_amount_offer10 paidrt_ssp_amount_offer11 paidrt_ssp_amount_offer12)

// PAYMENT AMOUNT FOR JPAL SPONSORED INDIVIDUALS
// defines sample for the payment analysis w/in the first year since offerdate
// individuals sponsored by JPAL that should be paid for
g samplepayment_jpal=0
replace samplepayment_jpal=1 if enroll_2yrs==1&fullsubsidy==1&paidbyjpal==1
replace samplepayment_jpal=1 if enroll_2yrs==1&halfsubsidy==1&paidbyjpal==1
replace samplepayment_jpal=0 if enroll_2yrs==1&BPJSmatch==0
replace samplepayment_jpal=0 if enroll_2yrs==1&membership!="PEKERJA BUKAN PENERIMA UPAH"

// amount paid by offer date
forvalues month=1(1)12 {
	* rt payment amount
	cap drop temp_amount`month'
	g temp_amount`month'=payamount_offer`month' if samplepayment_jpal==1
	bysort hhid: egen paidrt_jpalamount_offer`month'=total(temp_amount`month')
	}

// defines payment variables
egen paidrt_jpal_amount=rsum(paidrt_jpalamount_offer1 paidrt_jpalamount_offer2 paidrt_jpalamount_offer3 paidrt_jpalamount_offer4 paidrt_jpalamount_offer5 paidrt_jpalamount_offer6 paidrt_jpalamount_offer7 paidrt_jpalamount_offer8 paidrt_jpalamount_offer9 paidrt_jpalamount_offer10 paidrt_jpalamount_offer11 paidrt_jpalamount_offer12)

// PAYMENT AMOUNT FOR ALL INDIVIDUALS
// defines sample for the payment analysis AFTER the first year since offerdate
// self-sponsored individuals that should be paid for
g samplepayment_all=0
replace samplepayment_all=1 if enroll_2yrs==1
replace samplepayment_all=0 if enroll_2yrs==1&BPJSmatch==0
replace samplepayment_all=0 if enroll_2yrs==1&membership!="PEKERJA BUKAN PENERIMA UPAH"

// paid status by offer date
// amount paid by offer date
bysort hhid: egen hhsize_payment_all=total(samplepayment_all)
forvalues month=1(1)24 {
	g temp_paid`month'=(paid_offer`month'==1&samplepayment_all==1)
	bysort hhid: egen numberpaid_all_offer`month'=total(temp_paid`month')
	g paidrt_all_offer`month'=(numberpaid_all_offer`month'==hhsize_payment_all&hhsize_payment_all!=0)
	
	* rt payment amount
	cap drop temp_amount`month'
	g temp_amount`month'=payamount_offer`month' if samplepayment_all==1
	bysort hhid: egen paidrt_allamount_offer`month'=total(temp_amount`month')
	}
	

// PAYMENT STATUS BY MONTH SINCE SIGNUP (ALL SAMPLES)
forvalues month=1(1)24 {
	g paid_signup`month'=(paystatus_signup`month'==1)
	
	cap drop temp_paid`month'
	g temp_paid`month'=(paid_signup`month'==1&samplepayment_all==1)
	bysort hhid: egen numberpaid_signup`month'=total(temp_paid`month')
	
	// ALL
	g paidrt_signup`month'=(numberpaid_signup`month'==hhsize_payment_all&hhsize_payment_all!=0)
	g paidrt_some_signup`month'=(numberpaid_signup`month'>0&numberpaid_signup`month'<hhsize_payment_all&hhsize_payment_all!=0)
	g paidrt_none_signup`month'=(numberpaid_signup`month'==0&hhsize_payment_all!=0)
	
	// SELF-SPONSORED
	* payment status
	cap drop temp_paid`month'
	g temp_paid`month'=(paid_signup`month'==1&samplepayment_ssp==1)
	bysort hhid: egen temp_numberpaid_signup`month'=total(temp_paid`month')
	g paidrt_ssp_signup`month'=(temp_numberpaid_signup`month'==hhsize_payment&hhsize_payment!=0)
	
	* payment amount
	cap drop temp_amount`month'
	g temp_amount`month'=payamount_signup`month' if samplepayment_ssp==1
	bysort hhid: egen paidrt_ssp_amount_signup`month'=total(temp_amount`month')
	
	// JPAL
	* rt payment amount
	cap drop temp_amount`month'
	g temp_amount`month'=payamount_signup`month' if samplepayment_jpal==1
	bysort hhid: egen paidrt_jpalamount_signup`month'=total(temp_amount`month')
	
	}

cap drop temp_*	
	
save data/working/baseline_with_payment.dta, replace
